//---------------------------------------------------------------------------
//
//	X68000 EMULATOR "XM6" UTILITY
//
//	Copyright (C) 2001-2006 ohD(ytanaka@ipc-tokai.or.jp)
//	[ FATt@CVXe ]
//
//---------------------------------------------------------------------------

#include "os.h"
#include "xm6util.h"
#include "filepath.h"
#include "fileio.h"
#include "fdi.h"

//===========================================================================
//
//	FDIZN^
//
//===========================================================================

//---------------------------------------------------------------------------
//
//	RXgN^
//
//---------------------------------------------------------------------------
FDISector::FDISector(BOOL mfm, const DWORD *chrn)
{
	int i;

	ASSERT(chrn);

	// CHRN,MFML
	for (i=0; i<4; i++) {
		sec.chrn[i] = chrn[i];
	}
	sec.mfm = mfm;

	// ̑
	sec.error = FDD_NODATA;
	sec.length = 0;
	sec.buffer = NULL;
	sec.pos = 0;
	sec.changed = FALSE;
	sec.next = NULL;
}

//---------------------------------------------------------------------------
//
//	fXgN^
//
//---------------------------------------------------------------------------
FDISector::~FDISector()
{
	// 
	if (sec.buffer) {
		delete[] sec.buffer;
		sec.buffer = NULL;
	}
}

//---------------------------------------------------------------------------
//
//	[h
//
//---------------------------------------------------------------------------
void FASTCALL FDISector::Load(const BYTE *buf, int len, int err)
{
	ASSERT(this);
	ASSERT(!sec.buffer);
	ASSERT(sec.length == 0);
	ASSERT(buf);
	ASSERT(len > 0);

	// OXɐݒ
	sec.length = len;

	// obt@m
	try {
		sec.buffer = new BYTE[len];
	}
	catch (...) {
		sec.buffer = NULL;
		sec.length = 0;
	}
	if (!sec.buffer) {
		sec.length = 0;
	}

	// ]
	memcpy(sec.buffer, buf, sec.length);

	// [Nݒ
	sec.error = err;
	sec.changed = FALSE;
}

//---------------------------------------------------------------------------
//
//	ZN^}b`邩
//
//---------------------------------------------------------------------------
BOOL FASTCALL FDISector::IsMatch(BOOL mfm, const DWORD *chrn) const
{
	int i;

	ASSERT(this);
	ASSERT(chrn);

	// MFMr
	if (sec.mfm != mfm) {
		return FALSE;
	}

	// CHRr
	for (i=0; i<3; i++) {
		if (chrn[i] != sec.chrn[i]) {
			return FALSE;
		}
	}

	// N!=0̏ꍇ̂݁ANr
	if (chrn[3] != 0) {
		if (chrn[3] != sec.chrn[3]) {
			return FALSE;
		}
	}

	return TRUE;
}

//---------------------------------------------------------------------------
//
//	CHRN擾
//
//---------------------------------------------------------------------------
void FASTCALL FDISector::GetCHRN(DWORD *chrn) const
{
	int i;

	ASSERT(this);
	ASSERT(chrn);

	for (i=0; i<4; i++) {
		chrn[i] = sec.chrn[i];
	}
}

//---------------------------------------------------------------------------
//
//	[h
//
//---------------------------------------------------------------------------
int FASTCALL FDISector::Read(BYTE *buf) const
{
	ASSERT(this);
	ASSERT(buf);

	// ZN^obt@ȂΉȂ
	if (!sec.buffer) {
		return sec.error;
	}

	// ]{G[Ԃ
	memcpy(buf, sec.buffer, sec.length);
	return sec.error;
}

//---------------------------------------------------------------------------
//
//	Cg
//
//---------------------------------------------------------------------------
int FASTCALL FDISector::Write(const BYTE *buf, BOOL deleted)
{
	ASSERT(this);
	ASSERT(buf);

	// ZN^obt@ȂΉȂ
	if (!sec.buffer) {
		return sec.error;
	}

	// G[ɍs
	sec.error &= ~FDD_DATACRC;
	sec.error &= ~FDD_DDAM;
	if (deleted) {
		sec.error |= FDD_DDAM;
	}

	// vΉȂ
	if (memcmp(sec.buffer, buf, sec.length) == 0) {
		return sec.error;
	}

	// ]
	memcpy(sec.buffer, buf, sec.length);

	// XVtOāAG[Ԃ
	sec.changed = TRUE;
	return sec.error;
}

//---------------------------------------------------------------------------
//
//	tB
//
//---------------------------------------------------------------------------
int FASTCALL FDISector::Fill(DWORD d)
{
	int i;
	BOOL changed;

	ASSERT(this);

	// ZN^obt@ȂΉȂ
	if (!sec.buffer) {
		return sec.error;
	}

	// rȂ珑
	changed = FALSE;
	for (i=0; i<sec.length; i++) {
		if (sec.buffer[i] != (BYTE)d) {
			// 1łAtBbreak
			memset(sec.buffer, d, sec.length);
			changed = TRUE;
			break;
		}
	}

	// ݂ł̓f[^CRC͔Ȃ̂Ƃ
	sec.error &= ~FDD_DATACRC;

	// XVtOāAG[Ԃ
	if (changed) {
		sec.changed = TRUE;
	}
	return sec.error;
}

//===========================================================================
//
//	FDIgbN
//
//===========================================================================

//---------------------------------------------------------------------------
//
//	RXgN^
//
//---------------------------------------------------------------------------
FDITrack::FDITrack(FDIDisk *disk, int track, BOOL hd)
{
	ASSERT(disk);
	ASSERT((track >= 0) && (track <= 163));

	// fBXNAgbNL
	trk.disk = disk;
	trk.track = track;

	// ̑[NGA
	trk.init = FALSE;
	trk.sectors[0] = 0;
	trk.sectors[1] = 0;
	trk.sectors[2] = 0;
	trk.hd = hd;
	trk.mfm = TRUE;
	trk.first = NULL;
	trk.next = NULL;
}

//---------------------------------------------------------------------------
//
//	fXgN^
//
//---------------------------------------------------------------------------
FDITrack::~FDITrack()
{
	// NA
	ClrSector();
}

//---------------------------------------------------------------------------
//
//	Z[u
//	2HD,DIMȂǂ̃ZN^A݃^Cv
//
//---------------------------------------------------------------------------
BOOL FASTCALL FDITrack::Save(const Filepath& path, DWORD offset)
{
	Fileio fio;
	FDISector *sector;
	BOOL changed;

	ASSERT(this);

	// ĂȂΏޕKvȂ
	if (!IsInit()) {
		return TRUE;
	}

	// ZN^܂āA܂ĂZN^邩
	sector = GetFirst();
	changed = FALSE;
	while (sector) {
		if (sector->IsChanged()) {
			changed = TRUE;
		}
		sector = sector->GetNext();
	}

	// ǂ܂ĂȂΉȂ
	if (!changed) {
		return TRUE;
	}

	// t@CI[v
	if (!fio.Open(path, Fileio::ReadWrite)) {
		return FALSE;
	}

	// [v
	sector = GetFirst();
	while (sector) {
		// ύXĂȂ΁A
		if (!sector->IsChanged()) {
			offset += sector->GetLength();
			sector = sector->GetNext();
			continue;
		}

		// V[N
		if (!fio.Seek(offset)) {
			fio.Close();
			return FALSE;
		}

		// 
		if (!fio.Write(sector->GetSector(), sector->GetLength())) {
			fio.Close();
			return FALSE;
		}

		// tO𗎂Ƃ
		sector->ClrChanged();

		// 
		offset += sector->GetLength();
		sector = sector->GetNext();
	}

	// I
	fio.Close();
	return TRUE;
}

//---------------------------------------------------------------------------
//
//	Z[u
//	2HD,DIMȂǂ̃ZN^A݃^Cv
//
//---------------------------------------------------------------------------
BOOL FASTCALL FDITrack::Save(Fileio *fio, DWORD offset)
{
	FDISector *sector;
	BOOL changed;

	ASSERT(this);
	ASSERT(fio);

	// ĂȂΏޕKvȂ
	if (!IsInit()) {
		return TRUE;
	}

	// ZN^܂āA܂ĂZN^邩
	sector = GetFirst();
	changed = FALSE;
	while (sector) {
		if (sector->IsChanged()) {
			changed = TRUE;
		}
		sector = sector->GetNext();
	}

	// ǂ܂ĂȂΉȂ
	if (!changed) {
		return TRUE;
	}

	// [v
	sector = GetFirst();
	while (sector) {
		// ύXĂȂ΁A
		if (!sector->IsChanged()) {
			offset += sector->GetLength();
			sector = sector->GetNext();
			continue;
		}

		// V[N
		if (!fio->Seek(offset)) {
			return FALSE;
		}

		// 
		if (!fio->Write(sector->GetSector(), sector->GetLength())) {
			return FALSE;
		}

		// tO𗎂Ƃ
		sector->ClrChanged();

		// 
		offset += sector->GetLength();
		sector = sector->GetNext();
	}

	// I
	return TRUE;
}

//---------------------------------------------------------------------------
//
//	[hZN^
//	̃Xe[^XԂ(G[OR)
//		FDD_NOERROR		G[Ȃ
//		FDD_MAM			w薧xł̓AtH[}bg
//		FDD_NODATA		w薧xł̓AtH[}bgA
//						܂͗LȃZN^SRvȂ
//		FDD_NOCYL		IDCvAFFłȂZN^
//		FDD_BADCYL		IDCvAFFƂȂĂZN^
//		FDD_IDCRC		IDtB[hCRCG[
//		FDD_DATACRC		DATAtB[hCRCG[
//		FDD_DDAM		f[ebhZN^ł
//
//---------------------------------------------------------------------------
int FASTCALL FDITrack::ReadSector(BYTE *buf, int *len, BOOL mfm, const DWORD *chrn)
{
	FDISector *sector;
	DWORD work[4];
	int status;
	int i;
	int num;

	ASSERT(this);
	ASSERT(len);
	ASSERT(chrn);

	// xZN^擾
	if (mfm) {
		num = GetMFMSectors();
	}
	else {
		num = GetFMSectors();
	}

	// 0ȂMAM,NODATA(ZN^͂PȂ)
	if (num == 0) {
		return FDD_NODATA | FDD_MAM;
	}

	// ŏ̃ZN^擾
	sector = GetFirst();

	// Number[vAZN^(RȂ)
	status = FDD_NOERROR;
	num = GetAllSectors();
	for (i=0; i<num; i++) {
		// ZN^͕K
		ASSERT(sector);

		// x}b`ȂΌJԂ
		if (sector->IsMFM() != mfm) {
			sector = sector->GetNext();
			continue;
		}

		// CHRN擾AC`FbN
		sector->GetCHRN(work);
		if (work[0] != chrn[0]) {
			if (work[0] == 0xff) {
				status |= FDD_BADCYL;
			}
			else {
				status |= FDD_NOCYL;
			}
		}

		// RvŔ
		if (work[2] == chrn[2]) {
			break;
		}

		// ̃ZN^
		sector = sector->GetNext();
	}

	// RvȂ΁ANODATAŕԂ
	if (work[2] != chrn[2]) {
		status |= FDD_NODATA;
		return status;
	}

	// bufw肳Ăꍇ̂݁Aobt@փf[^BNULLȂXe[^X̂
	*len = sector->GetLength();
	if (buf) {
		status = sector->Read(buf);
	}
	else {
		status = sector->GetError();
	}

	// Xe[^X}XN
	status &= (FDD_IDCRC | FDD_DATACRC | FDD_DDAM);
	return status;
}

//---------------------------------------------------------------------------
//
//	CgZN^
//	̃Xe[^XԂ(G[OR)
//		FDD_NOERROR		G[Ȃ
//		FDD_MAM			w薧xł̓AtH[}bg
//		FDD_NODATA		w薧xł̓AtH[}bgA
//						܂͗LȃZN^SCHRNvȂ
//		FDD_NOCYL		IDCvAFFłȂZN^
//		FDD_BADCYL		IDCvAFFƂȂĂZN^
//		FDD_IDCRC		IDtB[hCRCG[
//		FDD_DDAM		f[ebhZN^ł
//
//---------------------------------------------------------------------------
int FASTCALL FDITrack::WriteSector(const BYTE *buf, int *len, BOOL mfm, const DWORD *chrn, BOOL deleted)
{
	FDISector *sector;
	DWORD work[4];
	int status;
	int i;
	int num;

	ASSERT(this);
	ASSERT(len);
	ASSERT(chrn);

	// xZN^擾
	if (mfm) {
		num = GetMFMSectors();
	}
	else {
		num = GetFMSectors();
	}

	// 0ȂMAM,NODATA(ZN^͂PȂ)
	if (num == 0) {
		return FDD_NODATA | FDD_MAM;
	}

	// ŏ̃ZN^擾
	sector = GetFirst();

	// Number[vAZN^(CHRN`FbN)
	status = FDD_NOERROR;
	num = GetAllSectors();
	for (i=0; i<num; i++) {
		// ZN^͕K
		ASSERT(sector);

		// x}b`ȂΌJԂ
		if (sector->IsMFM() != mfm) {
			sector = sector->GetNext();
			continue;
		}

		// CHRN擾AC`FbN
		sector->GetCHRN(work);
		if (work[0] != chrn[0]) {
			if (work[0] == 0xff) {
				status |= FDD_BADCYL;
			}
			else {
				status |= FDD_NOCYL;
			}
		}

		// CHRNvŔ
		if (sector->IsMatch(mfm, chrn)) {
			break;
		}

		// ̃ZN^
		sector = sector->GetNext();
	}

	// ZN^Ȃ΁ANODATA
	if (i >= num) {
		status |= FDD_NODATA;
		return status;
	}

	// bufw肳Ăꍇ̂݁AށBNULLȂXe[^X̂
	*len = sector->GetLength();
	if (buf) {
		status = sector->Write(buf, deleted);
	}
	else {
		status = sector->GetError();
	}

	// Xe[^X}XN
	status &= (FDD_IDCRC | FDD_DDAM);
	return status;
}

//---------------------------------------------------------------------------
//
//	ύX`FbN
//
//---------------------------------------------------------------------------
BOOL FASTCALL FDITrack::IsChanged() const
{
	BOOL changed;
	FDISector *sector;

	ASSERT(this);

	// 
	changed = FALSE;
	sector = GetFirst();

	// OR
	while (sector) {
		if (sector->IsChanged()) {
			changed = TRUE;
		}
		sector = sector->GetNext();
	}

	return changed;
}

//---------------------------------------------------------------------------
//
//	ZN^OX݌vZo
//
//---------------------------------------------------------------------------
DWORD FASTCALL FDITrack::GetTotalLength() const
{
	DWORD total;
	FDISector *sector;

	ASSERT(this);

	// 
	total = 0;
	sector = GetFirst();

	// [v
	while (sector) {
		total += sector->GetLength();
		sector = sector->GetNext();
	}

	return total;
}

//---------------------------------------------------------------------------
//
//	ύX
//
//---------------------------------------------------------------------------
void FASTCALL FDITrack::ForceChanged()
{
	FDISector *sector;

	ASSERT(this);

	// 
	sector = GetFirst();

	// [v
	while (sector) {
		sector->ForceChanged();
		sector = sector->GetNext();
	}
}

//---------------------------------------------------------------------------
//
//	ZN^ǉ
//
//---------------------------------------------------------------------------
void FASTCALL FDITrack::AddSector(FDISector *sector)
{
	FDISector *ptr;

	ASSERT(this);
	ASSERT(sector);

	// ZN^ĂȂ΁Â܂ܒǉ
	if (!trk.first) {
		trk.first = sector;
		sector->SetNext(NULL);

		// MFM
		trk.mfm = sector->IsMFM();
	}
	else {
		// ŏIZN^𓾂
		ptr = trk.first;
			while (ptr->GetNext()) {
			ptr = ptr->GetNext();
		}

		// ŏIZN^ɒǉ
		ptr->SetNext(sector);
		sector->SetNext(NULL);
	}

	// Z
	trk.sectors[0]++;
	if (sector->IsMFM()) {
		trk.sectors[1]++;
	}
	else {
		trk.sectors[2]++;
	}
}

//---------------------------------------------------------------------------
//
//	ZN^S폜
//
//---------------------------------------------------------------------------
void FASTCALL FDITrack::ClrSector()
{
	FDISector *sector;

	ASSERT(this);

	// ZN^ׂč폜
	while (trk.first) {
		sector = trk.first->GetNext();
		delete trk.first;
		trk.first = sector;
	}

	// 0
	trk.sectors[0] = 0;
	trk.sectors[1] = 0;
	trk.sectors[2] = 0;
}

//---------------------------------------------------------------------------
//
//	ZN^
//
//---------------------------------------------------------------------------
FDISector* FASTCALL FDITrack::Search(BOOL mfm, const DWORD *chrn)
{
	FDISector *sector;

	ASSERT(this);
	ASSERT(chrn);

	// ŏ̃ZN^擾
	sector = GetFirst();

	// [v
	while (sector) {
		// }b`΂̃ZN^Ԃ
		if (sector->IsMatch(mfm, chrn)) {
			return sector;
		}

		sector = sector->GetNext();
	}

	// }b`Ȃ
	return NULL;
}

//===========================================================================
//
//	FDIfBXN
//
//===========================================================================

//---------------------------------------------------------------------------
//
//	RXgN^
//
//---------------------------------------------------------------------------
FDIDisk::FDIDisk(int index, FDI *fdi)
{
	ASSERT((index >= 0) && (index < 0x10));

	// CfbNXAIDw
	disk.index = index;
	disk.fdi = fdi;
	disk.id = MAKEID('I', 'N', 'I', 'T');

	// 
	disk.writep = FALSE;
	disk.readonly = FALSE;

	// ̂Ȃ
	disk.name[0] = '\0';
	disk.offset = 0;

	// ێgbNȂ
	disk.first = NULL;
	disk.head[0] = NULL;
	disk.head[1] = NULL;

	// NȂ
	disk.next = NULL;
}

//---------------------------------------------------------------------------
//
//	fXgN^
//
//---------------------------------------------------------------------------
FDIDisk::~FDIDisk()
{
	// tbV
	Flush();

	// NA
	ClrTrack();
}

//---------------------------------------------------------------------------
//
//	I[v
//	hNX̒ӓ_F
//		writep, readonlyK؂ɐݒ肷
//		path, nameK؂ɐݒ肷
//	ʃNX̒ӓ_F
//		ĂяoŁÃ݂V_փV[N
//
//---------------------------------------------------------------------------
BOOL FASTCALL FDIDisk::Open(const Filepath& /*path*/, DWORD /*offset*/)
{
	// zNXI
	ASSERT(FALSE);
	return FALSE;
}

//---------------------------------------------------------------------------
//
//	݋֎~ݒ
//
//---------------------------------------------------------------------------
void FASTCALL FDIDisk::WriteP(BOOL flag)
{
	ASSERT(this);

	// ReadOnlyȂAɏ݋֎~
	if (IsReadOnly()) {
		disk.writep = TRUE;
		return;
	}

	// ݒ
	disk.writep = flag;
}

//---------------------------------------------------------------------------
//
//	tbV
//
//---------------------------------------------------------------------------
BOOL FASTCALL FDIDisk::Flush()
{
	ASSERT(this);

	// Ȃ
	return TRUE;
}

//---------------------------------------------------------------------------
//
//	fBXN擾
//
//---------------------------------------------------------------------------
void FASTCALL FDIDisk::GetName(char *buf) const
{
	ASSERT(this);
	ASSERT(buf);

	strcpy(buf, disk.name);
}

//---------------------------------------------------------------------------
//
//	pX擾
//
//---------------------------------------------------------------------------
void FASTCALL FDIDisk::GetPath(Filepath& path) const
{
	ASSERT(this);

	// 
	path = disk.path;
}

//---------------------------------------------------------------------------
//
//	V[N
//	hNX̒ӓ_F
//		݂head[]t@Cɏ߂AVgbN[hAhead[]փZbg
//
//---------------------------------------------------------------------------
void FASTCALL FDIDisk::Seek(int /*c*/)
{
	ASSERT(this);
}

//---------------------------------------------------------------------------
//
//	[hZN^
//	̃Xe[^XԂ(G[OR)
//		FDD_NOERROR		G[Ȃ
//		FDD_MAM			w薧xł̓AtH[}bg
//		FDD_NODATA		w薧xł̓AtH[}bgA
//						܂͗LȃZN^SRvȂ
//		FDD_NOCYL		IDCvłAFFłȂZN^
//		FDD_BADCYL		IDCvAFFƂȂĂZN^
//		FDD_IDCRC		IDtB[hCRCG[
//		FDD_DATACRC		DATAtB[hCRCG[
//		FDD_DDAM		f[ebhZN^ł
//
//---------------------------------------------------------------------------
int FASTCALL FDIDisk::ReadSector(BYTE *buf, int *len, BOOL mfm, const DWORD *chrn, int hd)
{
	FDITrack *track;

	ASSERT(this);
	ASSERT(len);
	ASSERT(chrn);
	ASSERT((hd == 0) || (hd == 4));

	// gbN擾
	if (hd == 0) {
		track = GetHead(0);
	}
	else {
		track = GetHead(1);
	}

	// NULLȂNODATA
	if (!track) {
		// NODATA
		return FDD_MAM | FDD_NODATA;
	}

	// gbNɔC
	return track->ReadSector(buf, len, mfm, chrn);
}

//---------------------------------------------------------------------------
//
//	CgZN^
//	̃Xe[^XԂ(G[OR)
//		FDD_NOERROR		G[Ȃ
//		FDD_NOTWRITE	fBA͏݋֎~
//		FDD_MAM			w薧xł̓AtH[}bg
//		FDD_NODATA		w薧xł̓AtH[}bgA
//						܂͗LȃZN^SRvȂ
//		FDD_NOCYL		IDCvłAFFłȂZN^
//		FDD_BADCYL		IDCvAFFƂȂĂZN^
//		FDD_IDCRC		IDtB[hCRCG[
//		FDD_DDAM		f[ebhZN^ł
//
//---------------------------------------------------------------------------
int FASTCALL FDIDisk::WriteSector(const BYTE *buf, int *len, BOOL mfm, const DWORD *chrn, int hd, BOOL deleted)
{
	FDITrack *track;

	ASSERT(this);
	ASSERT(len);
	ASSERT(chrn);
	ASSERT((hd == 0) || (hd == 4));

	// ݃`FbN
	if (IsWriteP()) {
		return FDD_NOTWRITE;
	}

	// gbN擾
	if (hd == 0) {
		track = GetHead(0);
	}
	else {
		track = GetHead(1);
	}

	// NULLȂNODATA
	if (!track) {
		// NODATA
		return FDD_MAM | FDD_NODATA;
	}

	// gbNɔC
	return track->WriteSector(buf, len, mfm, chrn, deleted);
}

//---------------------------------------------------------------------------
//
//	gbNǉ
//
//---------------------------------------------------------------------------
void FASTCALL FDIDisk::AddTrack(FDITrack *track)
{
	FDITrack *ptr;

	ASSERT(this);
	ASSERT(track);

	// gbNĂȂ΁Â܂ܒǉ
	if (!disk.first) {
		disk.first = track;
		disk.first->SetNext(NULL);
		return;
	}

	// ŏIgbN𓾂
	ptr = disk.first;
	while (ptr->GetNext()) {
		ptr = ptr->GetNext();
	}

	// ŏIgbNɒǉ
	ptr->SetNext(track);
	track->SetNext(NULL);
}

//---------------------------------------------------------------------------
//
//	gbNS폜
//
//---------------------------------------------------------------------------
void FASTCALL FDIDisk::ClrTrack()
{
	FDITrack *track;

	ASSERT(this);

	// gbNׂč폜
	while (disk.first) {
		track = disk.first->GetNext();
		delete disk.first;
		disk.first = track;
	}
}

//---------------------------------------------------------------------------
//
//	gbNT[`
//
//---------------------------------------------------------------------------
FDITrack* FASTCALL FDIDisk::Search(int track) const
{
	FDITrack *p;

	ASSERT(this);
	ASSERT((track >= 0) && (track <= 163));

	// ŏ̃gbN擾
	p = GetFirst();

	// [v
	while (p) {
		if (p->GetTrack() == track) {
			return p;
		}
		p = p->GetNext();
	}

	// Ȃ
	return NULL;
}

//===========================================================================
//
//	FDIgbN(2HD)
//
//===========================================================================

//---------------------------------------------------------------------------
//
//	RXgN^
//
//---------------------------------------------------------------------------
FDITrack2HD::FDITrack2HD(FDIDisk *disk, int track) : FDITrack(disk, track)
{
	ASSERT(disk);
}

//---------------------------------------------------------------------------
//
//	[h
//
//---------------------------------------------------------------------------
BOOL FASTCALL FDITrack2HD::Load(const Filepath& path, DWORD offset)
{
	Fileio fio;
	BYTE buf[0x400];
	DWORD chrn[4];
	int i;
	FDISector *sector;

	ASSERT(this);
	ASSERT((offset & 0x1fff) == 0);
	ASSERT(offset < 0x134000);

	// ς݂Ȃsv(V[NɌĂ΂̂ŁAPxǂŃLbV)
	if (IsInit()) {
		return TRUE;
	}

	// ZN^݂Ȃ
	ASSERT(!GetFirst());
	ASSERT(GetAllSectors() == 0);
	ASSERT(GetMFMSectors() == 0);
	ASSERT(GetFMSectors() == 0);

	// CEHEN
	chrn[0] = GetTrack() >> 1;
	chrn[1] = GetTrack() & 1;
	chrn[3] = 3;

	// ǂݍ݃I[v
	if (!fio.Open(path, Fileio::ReadOnly)) {
		return FALSE;
	}

	// V[N
	if (!fio.Seek(offset)) {
		fio.Close();
		return FALSE;
	}

	// [v
	for (i=0; i<8; i++) {
		// f[^ǂݍ
		if (!fio.Read(buf, sizeof(buf))) {
			// r܂Œǉ폜
			ClrSector();
			fio.Close();
			return FALSE;
		}

		// ZN^쐬
		chrn[2] = i + 1;
		sector = new FDISector(TRUE, chrn);
		sector->Load(buf, sizeof(buf), FDD_NOERROR);

		// ZN^ǉ
		AddSector(sector);
	}

	// N[Y
	fio.Close();

	// ok
	trk.init = TRUE;
	return TRUE;
}

//===========================================================================
//
//	FDIfBXN(2HD)
//
//===========================================================================

//---------------------------------------------------------------------------
//
//	RXgN^
//
//---------------------------------------------------------------------------
FDIDisk2HD::FDIDisk2HD(int index, FDI *fdi) : FDIDisk(index, fdi)
{
	// IDݒ
	disk.id = MAKEID('2', 'H', 'D', ' ');
}

//---------------------------------------------------------------------------
//
//	I[v
//
//---------------------------------------------------------------------------
BOOL FASTCALL FDIDisk2HD::Open(const Filepath& path, DWORD offset)
{
	Fileio fio;
	DWORD size;
	FDITrack2HD *track;
	int i;

	ASSERT(this);
	ASSERT(offset == 0);
	ASSERT(!GetFirst());
	ASSERT(!GetHead(0));
	ASSERT(!GetHead(1));

	// ݉\Ƃď
	disk.writep = FALSE;
	disk.readonly = FALSE;

	// I[vł邱Ƃm߂
	if (!fio.Open(path, Fileio::ReadWrite)) {
		// ǂݍ݃I[v݂
		if (!fio.Open(path, Fileio::ReadOnly)) {
			return FALSE;
		}

		// ǂݍ݂͉\
		disk.writep = TRUE;
		disk.readonly = TRUE;
	}

	// t@CTCY1261568ł邱Ƃm߂
	size = fio.GetFileSize();
	if (size != 1261568) {
		fio.Close();
		return FALSE;
	}
	fio.Close();

	// pXAItZbgL
	disk.path = path;
	disk.offset = offset;

	// fBXN̓t@C{gqƂ
	strcpy(disk.name, path.GetShort());

	// gbN쐬(0`76V_܂ŁA77*2gbN)
	for (i=0; i<154; i++) {
		track = new FDITrack2HD(this, i);
		AddTrack(track);
	}

	// I
	return TRUE;
}

//---------------------------------------------------------------------------
//
//	V[N
//
//---------------------------------------------------------------------------
void FASTCALL FDIDisk2HD::Seek(int c)
{
	int i;
	FDITrack2HD *track;
	DWORD offset;

	ASSERT(this);
	ASSERT((c >= 0) && (c < 82));

	// c75܂ŋB͈͊Ołhead[i]=NULLƂ
	if ((c < 0) || (c > 76)) {
		disk.head[0] = NULL;
		disk.head[1] = NULL;
		return;
	}

	// YgbNA[h
	for (i=0; i<2; i++) {
		// gbN
		track = (FDITrack2HD*)Search(c * 2 + i);
		ASSERT(track);
		disk.head[i] = track;

		// gbNioAItZbgZo(x8KB)
		offset = track->GetTrack();
		offset <<= 13;

		// [h
		track->Load(disk.path, offset);
	}
}

//---------------------------------------------------------------------------
//
//	tbV
//
//---------------------------------------------------------------------------
BOOL FASTCALL FDIDisk2HD::Flush()
{
	int i;
	DWORD offset;
	FDITrack *track;
	BOOL changed;
	Fileio fio;

	ASSERT(this);

	// ݕKvȂ
	changed = FALSE;

	// gbNāAݕKv
	for (i=0; i<154; i++) {
		// gbN
		track = (FDITrack2HD*)Search(i);
		ASSERT(track);

		// Kv`FbN
		if (track->IsChanged()) {
			changed = TRUE;
		}
	}

	// KvȂ΁A܂
	if (!changed) {
		return TRUE;
	}

	// I[vƃItZbg
	if (!fio.Open(disk.path, Fileio::ReadWrite)) {
		return FALSE;
	}
	offset = 0;

	// gbNāA
	for (i=0; i<154; i++) {
		// gbN
		track = (FDITrack2HD*)Search(i);
		ASSERT(track);

		// 
		track->Save(&fio, offset);

		// ̃ItZbg(1gbN=8KB)
		offset += 0x2000;
	}

	// I
	fio.Close();

	return TRUE;
}
