//---------------------------------------------------------------------------
//
//	X68000 EMULATOR "XM6" UTILITY
//
//	Copyright (C) 2001-2006 ohD(ytanaka@ipc-tokai.or.jp)
//	[ SCSI-ROM ]
//
//---------------------------------------------------------------------------

#include "os.h"
#include "xm6util.h"
#include "filepath.h"
#include "fileio.h"
#include "fatname.h"
#include "fatfs.h"
#include "scsirom.h"

//===========================================================================
//
//	SCSI-ROM
//
//===========================================================================

//---------------------------------------------------------------------------
//
//	Human68k(version3.02) fBXNC[Wt@C
//
//---------------------------------------------------------------------------
#if defined(_WIN32)
#define HUMAN302		_T("HUMAN302.XDF")
#else
#define HUMAN302		"HUMAN302.XDF"
#endif	// _WIN32

//---------------------------------------------------------------------------
//
//	ΏۃpXƃt@Cʒu
//	At@C}b`ǂ邱ƁB̓fBNg\ɂ킹
//
//---------------------------------------------------------------------------
#if defined(_WIN32)
#define FORMAT_X		_T("/BIN        /FORMAT  X  ")
#else
#define FORMAT_X		"/BIN        /FORMAT  X  "
#endif	// _WIN32
#define FORMAT_SIZE		91010			// FORMAT.x v2.31
#define FORMAT_START	0xac94			// SCSI IOCSJnItZbg
#define FORMAT_END		0xc3ca			// SCSI IOCSIItZbg

//---------------------------------------------------------------------------
//
//	RXgN^
//
//---------------------------------------------------------------------------
SCSIROM::SCSIROM()
{
	// t@CVXe
	fs = NULL;
}

//---------------------------------------------------------------------------
//
//	fXgN^
//
//---------------------------------------------------------------------------
SCSIROM::~SCSIROM()
{
	ASSERT(!fs);
}

//---------------------------------------------------------------------------
//
//	
//
//---------------------------------------------------------------------------
BOOL FASTCALL SCSIROM::Init()
{
	Filepath path;
	Fileio fio;

	ASSERT(this);

	// t@CLƁAt@CTCY`FbN
	path.SetPath(HUMAN302);
	path.SetBaseDir();
	if (!fio.Open(path, Fileio::ReadOnly)) {
		// t@CȂ
		return FALSE;
	}
	if (fio.GetFileSize() != 0x134000) {
		// t@CTCYقȂ
		return FALSE;
	}
	fio.Close();

	// t@CVXe쐬
	ASSERT(!fs);
	fs = new FATFs;
	ASSERT(fs);

	return TRUE;
}

//---------------------------------------------------------------------------
//
//	N[Abv
//
//---------------------------------------------------------------------------
void FASTCALL SCSIROM::Cleanup()
{
	ASSERT(this);

	// t@CVXe폜
	if (fs) {
		delete fs;
		fs = NULL;
	}
}

//---------------------------------------------------------------------------
//
//	쐬
//
//---------------------------------------------------------------------------
BOOL FASTCALL SCSIROM::Create(BOOL exrom, DWORD ver)
{
	DWORD base;
	DWORD offset;
	int vector;
	char version[8];
	Filepath path;
	Fileio fio;
	FATName name;

	ASSERT(this);
	ASSERT(ver >= 0x0200);
	ASSERT(fs);

	// obt@0ŃNA
	memset(ROM, 0, sizeof(ROM));

	// NRs[
	if (exrom) {
		memcpy(ROM, SCSIEX, sizeof(SCSIEX));
	}
	else {
		memcpy(ROM, SCSIIN, sizeof(SCSIIN));
	}

	// x[XAhXƁAItZbgAhXݒ
	if (exrom) {
		// Ot̓AhX$EA0000n܂B擪0x20oCg̓WX^GA
		base = 0xea0000;
		offset = 0x000020;
	}
	else {
		// ̓AhX$FC0000n܂BWX^GA݂͑Ȃ
		base = 0xfc0000;
		offset = 0;
	}

	// xN^GA~9
	for (vector=0; vector<9; vector++) {
		AddLong(base, &ROM[offset + vector * 4]);
	}

	// Human68kւ̃Wve[u
	if (exrom) {
		AddLong(base, &ROM[0x82]);
		AddLong(base, &ROM[0x86]);
	}
	else {
		AddLong(base, &ROM[0x60]);
		AddLong(base, &ROM[0x64]);
	}

	// SCSI IOCS̈ʒu
	if (exrom) {
		offset = sizeof(SCSIEX);
	}
	else {
		offset = sizeof(SCSIIN);
	}

	// HUMAN302.XDFA^b`
	path.SetPath(HUMAN302);
	path.SetBaseDir();
	if (!fs->Attach(path, FST_HUMAN)) {
		return FALSE;
	}

	// FORMAT.x̃C[Wǂݏo
	name.SetName(FORMAT_X);
	if (!fs->Open(name, FATFs::ReadOnly)) {
		fs->Close();
		fs->Detach();
		return FALSE;
	}
	if (fs->GetSize() != FORMAT_SIZE) {
		fs->Close();
		fs->Detach();
		return FALSE;
	}
	if (!fs->Read(FORMAT)) {
		fs->Close();
		fs->Detach();
		return FALSE;
	}
	fs->Close();

	// HUMAN302.XDFf^b`
	fs->Detach();

	// wItZbgAwTCY܂łRs[
	memcpy(&ROM[offset], &FORMAT[FORMAT_START], FORMAT_END - FORMAT_START + 1);

	// SPCAhX
	if (exrom) {
		// Ot$EA0000
		ROM[offset + 0x134 + 0] = 0x00;
		ROM[offset + 0x134 + 1] = 0xea;
		ROM[offset + 0x134 + 2] = 0x00;
		ROM[offset + 0x134 + 3] = 0x00;
	}
	else {
		// $E96020
		ROM[offset + 0x134 + 0] = 0x00;
		ROM[offset + 0x134 + 1] = 0xe9;
		ROM[offset + 0x134 + 2] = 0x60;
		ROM[offset + 0x134 + 3] = 0x20;
	}

	// SCSI IOCSo[W(ver0004ver0001)
	ROM[offset + 0xfa6 + 0] = 0x70;
	ROM[offset + 0xfa6 + 1] = 0x01;

	// o[Wݒ
	strcpy((char*)&ROM[0x1ff8], "XM6 ");
	sprintf(version, "%01X.%02X", (BYTE)(ver >> 8), (BYTE)ver);
	memcpy(&ROM[0x1ffc], version, 4);

	// SCSIINROM.DAT܂SCSIEXROM.DATƂĕۑ
	if (exrom) {
		path.SysFile(Filepath::SCSIExt);
	}
	else {
		path.SysFile(Filepath::SCSIInt);
	}
	if (!fio.Open(path, Fileio::WriteOnly)) {
		return FALSE;
	}
	if (!fio.Write(ROM, sizeof(ROM))) {
		fio.Close();
		return FALSE;
	}
	fio.Close();

	return TRUE;
}

//---------------------------------------------------------------------------
//
//	LongZ
//
//---------------------------------------------------------------------------
void FASTCALL SCSIROM::AddLong(DWORD add, BYTE *ptr)
{
	DWORD value;

	ASSERT(this);
	ASSERT(ptr);

	// f[^rbOGfBAŎ擾
	value = (DWORD)ptr[0];
	value <<= 8;
	value |= (DWORD)ptr[1];
	value <<= 8;
	value |= (DWORD)ptr[2];
	value <<= 8;
	value |= (DWORD)ptr[3];

	// Z
	value += add;

	// ZʂrbOGfBAŊi[
	ptr[0] = (BYTE)(value >> 24);
	ptr[1] = (BYTE)(value >> 16);
	ptr[2] = (BYTE)(value >> 8);
	ptr[3] = (BYTE)value;
}

//---------------------------------------------------------------------------
//
//	SCSIN(SCSIIN)
//
//---------------------------------------------------------------------------
const BYTE SCSIROM::SCSIIN[864] = {
	0x00,0x00,0x00,0x70,0x00,0x00,0x00,0x70,
	0x00,0x00,0x00,0x70,0x00,0x00,0x00,0x70,
	0x00,0x00,0x00,0x70,0x00,0x00,0x00,0x70,
	0x00,0x00,0x00,0x70,0x00,0x00,0x00,0x70,
	0x00,0x00,0x00,0x30,0x53,0x43,0x53,0x49,
	0x49,0x4e,0x00,0x01,0x00,0xe9,0x60,0x20,
	0x43,0xfa,0x03,0x2e,0x43,0xe9,0x01,0x38,
	0x22,0x3c,0x00,0x00,0x01,0xf5,0x70,0x80,
	0x4e,0x4f,0xb0,0x89,0x67,0x14,0x72,0x00,
	0x70,0xf5,0x4e,0x4f,0x43,0xfa,0x02,0x90,
	0x72,0x2b,0x70,0x80,0x4e,0x4f,0x21,0xc0,
	0x0c,0xee,0x4e,0x75,0x53,0x43,0x53,0x49,
	0x00,0x00,0x01,0x32,0x00,0x00,0x04,0x98,
	0x48,0x75,0x6d,0x61,0x6e,0x36,0x38,0x6b,
	0x70,0x8e,0x4e,0x4f,0x78,0x00,0x18,0x00,
	0xe4,0x0c,0x02,0x04,0x00,0x07,0x0c,0x04,
	0x00,0x07,0x67,0x50,0x7c,0x03,0x43,0xfa,
	0x02,0xd8,0x43,0xe9,0x01,0x38,0x22,0x3c,
	0x00,0x00,0x01,0xf5,0x70,0x80,0x4e,0x4f,
	0xb0,0x89,0x67,0x14,0x72,0x00,0x70,0xf5,
	0x4e,0x4f,0x43,0xfa,0x02,0x3a,0x72,0x2b,
	0x70,0x80,0x4e,0x4f,0x21,0xc0,0x0c,0xee,
	0x72,0x24,0x70,0xf5,0x4e,0x4f,0x4a,0x80,
	0x67,0x1c,0x0c,0x00,0x00,0x02,0x66,0x14,
	0x43,0xf8,0x20,0x00,0x76,0x03,0x72,0x2c,
	0x70,0xf5,0x4e,0x4f,0x4a,0x80,0x66,0x04,
	0x51,0xce,0xff,0xde,0x4e,0x75,0x72,0x2b,
	0x70,0xf5,0x4e,0x4f,0x4a,0x80,0x66,0x50,
	0x43,0xf8,0x20,0x00,0x72,0x25,0x70,0xf5,
	0x4e,0x4f,0x4a,0x80,0x66,0x42,0x0c,0xa9,
	0x00,0x00,0x02,0x00,0x00,0x04,0x66,0x38,
	0x74,0x00,0x76,0x02,0x7a,0x01,0x72,0x26,
	0x70,0xf5,0x4e,0x4f,0x4a,0x80,0x66,0x28,
	0x0c,0x91,0x58,0x36,0x38,0x53,0x66,0x20,
	0x0c,0xa9,0x43,0x53,0x49,0x31,0x00,0x04,
	0x66,0x16,0x74,0x02,0x76,0x02,0x72,0x26,
	0x70,0xf5,0x4e,0x4f,0x4a,0x80,0x66,0x08,
	0x0c,0x11,0x00,0x60,0x66,0x02,0x4e,0x91,
	0x4e,0x75,0x48,0xe7,0xdf,0xfe,0x70,0x8e,
	0x4e,0x4f,0x02,0x80,0x00,0xff,0xff,0xff,
	0x7e,0xff,0x0c,0x80,0x00,0xfc,0x00,0x00,
	0x65,0x1c,0x0c,0x80,0x00,0xfc,0x00,0x24,
	0x64,0x14,0x0c,0x80,0x00,0xfc,0x00,0x20,
	0x67,0x3e,0x7e,0x00,0x1e,0x00,0xe4,0x0f,
	0x02,0x07,0x00,0x07,0x60,0x32,0x4a,0x02,
	0x66,0x2e,0x2f,0x09,0x43,0xfa,0x01,0xf2,
	0x43,0xe9,0x01,0x38,0x22,0x3c,0x00,0x00,
	0x01,0xf5,0x70,0x80,0x4e,0x4f,0xb0,0x89,
	0x67,0x14,0x72,0x00,0x70,0xf5,0x4e,0x4f,
	0x43,0xfa,0x01,0x54,0x72,0x2b,0x70,0x80,
	0x4e,0x4f,0x21,0xc0,0x0c,0xee,0x22,0x5f,
	0x0c,0x02,0x00,0x07,0x64,0x00,0x00,0xfe,
	0x78,0x00,0x18,0x02,0x7a,0x03,0x72,0x24,
	0x70,0xf5,0x4e,0x4f,0x4a,0x80,0x67,0x1e,
	0x0c,0x00,0x00,0x02,0x66,0x00,0x00,0xe0,
	0x76,0x03,0x72,0x2c,0x70,0xf5,0x4e,0x4f,
	0x4a,0x80,0x66,0x00,0x00,0xd2,0x51,0xcd,
	0xff,0xde,0x60,0x00,0x00,0xca,0x72,0x25,
	0x70,0xf5,0x4e,0x4f,0x4a,0x80,0x66,0x00,
	0x00,0xbe,0x0c,0xa9,0x00,0x00,0x02,0x00,
	0x00,0x04,0x66,0x00,0x00,0xb2,0x2c,0x02,
	0x74,0x04,0x76,0x02,0x7a,0x01,0x72,0x26,
	0x70,0xf5,0x4e,0x4f,0x24,0x06,0x4a,0x80,
	0x66,0x00,0x00,0x9c,0x0c,0x91,0x58,0x36,
	0x38,0x4b,0x66,0x00,0x00,0x92,0x48,0x42,
	0xb8,0x07,0x62,0x14,0x67,0x0a,0x72,0xff,
	0x61,0x00,0x00,0x92,0xd4,0x43,0x60,0x08,
	0x72,0x00,0x61,0x00,0x00,0x88,0xd4,0x43,
	0x48,0x42,0x2c,0x02,0x74,0x00,0x76,0x02,
	0x7a,0x01,0x72,0x26,0x70,0xf5,0x4e,0x4f,
	0x24,0x06,0x4a,0x80,0x66,0x60,0x0c,0x91,
	0x58,0x36,0x38,0x53,0x66,0x58,0x0c,0xa9,
	0x43,0x53,0x49,0x31,0x00,0x04,0x66,0x4e,
	0x74,0x06,0x76,0x1a,0x72,0x26,0x70,0xf5,
	0x4e,0x4f,0x24,0x06,0x4a,0x80,0x66,0x3e,
	0x0c,0xa9,0x01,0x53,0x43,0x48,0x00,0x0e,
	0x66,0x34,0x0c,0xa9,0x44,0x49,0x53,0x4b,
	0x00,0x12,0x66,0x2a,0x20,0x09,0xd1,0xa9,
	0x00,0x06,0xd1,0xa9,0x00,0x0a,0x20,0x11,
	0x52,0x80,0x67,0x0a,0x20,0x11,0xd0,0x89,
	0x22,0x80,0x22,0x40,0x60,0xd2,0x48,0x42,
	0x13,0x42,0x00,0x16,0x48,0x42,0x4c,0xdf,
	0x7f,0xfb,0x52,0x82,0x4e,0x75,0x52,0x82,
	0x60,0x00,0xfe,0xfe,0x4c,0xdf,0x7f,0xfb,
	0x74,0xff,0x4e,0x75,0x48,0xe7,0x20,0x40,
	0x74,0x0e,0x76,0x00,0x43,0xe9,0x00,0x10,
	0x4a,0x11,0x67,0x20,0x0c,0x91,0x48,0x75,
	0x6d,0x61,0x66,0x18,0x0c,0xa9,0x6e,0x36,
	0x38,0x6b,0x00,0x04,0x66,0x0e,0x10,0x29,
	0x00,0x08,0xe2,0x08,0x65,0x06,0x52,0x83,
	0x80,0x01,0x67,0x04,0x51,0xca,0xff,0xd6,
	0x4c,0xdf,0x02,0x04,0x4e,0x75,0x48,0xe7,
	0xff,0xfe,0xe2,0x08,0x65,0x20,0x30,0x38,
	0x0a,0x0e,0x0c,0x40,0x00,0x40,0x65,0x0c,
	0x0c,0x40,0x00,0x50,0x65,0x10,0x0c,0x40,
	0x00,0xf5,0x67,0x0a,0x4c,0xdf,0x7f,0xff,
	0x2f,0x38,0x0c,0xee,0x4e,0x75,0x4c,0xdf,
	0x7f,0xff,0x4e,0x73,0x20,0x53,0x43,0x53,
	0x49,0x2d,0x49,0x4f,0x43,0x53,0x20,0x62,
	0x69,0x6e,0x61,0x72,0x79,0x20,0x66,0x72,
	0x6f,0x6d,0x20,0x46,0x4f,0x52,0x4d,0x41,
	0x54,0x2e,0x78,0x20,0x43,0x6f,0x70,0x79,
	0x72,0x69,0x67,0x68,0x74,0x20,0x28,0x43,
	0x29,0x20,0x31,0x39,0x39,0x30,0x2d,0x31,
	0x39,0x39,0x33,0x20,0x53,0x48,0x41,0x52,
	0x50,0x2f,0x46,0x69,0x72,0x73,0x74,0x20,
	0x43,0x6c,0x61,0x73,0x73,0x20,0x54,0x65,
	0x63,0x68,0x6e,0x6f,0x6c,0x6f,0x67,0x79
};

//---------------------------------------------------------------------------
//
//	SCSIN(SCSIEX)
//
//---------------------------------------------------------------------------
const BYTE SCSIROM::SCSIEX[898] = {
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x92,0x00,0x00,0x00,0x92,
	0x00,0x00,0x00,0x92,0x00,0x00,0x00,0x92,
	0x00,0x00,0x00,0x92,0x00,0x00,0x00,0x92,
	0x00,0x00,0x00,0x92,0x00,0x00,0x00,0x92,
	0x00,0x00,0x00,0x50,0x53,0x43,0x53,0x49,
	0x45,0x58,0x00,0x01,0x00,0xea,0x00,0x00,
	0x4e,0x75,0x43,0xfa,0x03,0x2e,0x43,0xe9,
	0x01,0x38,0x22,0x3c,0x00,0x00,0x01,0xf5,
	0x70,0x80,0x4e,0x4f,0xb0,0x89,0x67,0x14,
	0x72,0x00,0x70,0xf5,0x4e,0x4f,0x43,0xfa,
	0x02,0x90,0x72,0x2b,0x70,0x80,0x4e,0x4f,
	0x21,0xc0,0x0c,0xee,0x4e,0x75,0x53,0x43,
	0x53,0x49,0x00,0x00,0x01,0x54,0x00,0x00,
	0x04,0xba,0x48,0x75,0x6d,0x61,0x6e,0x36,
	0x38,0x6b,0x70,0x8e,0x4e,0x4f,0x78,0x00,
	0x18,0x00,0xe4,0x0c,0x02,0x04,0x00,0x07,
	0x0c,0x04,0x00,0x07,0x67,0x50,0x7c,0x03,
	0x43,0xfa,0x02,0xd8,0x43,0xe9,0x01,0x38,
	0x22,0x3c,0x00,0x00,0x01,0xf5,0x70,0x80,
	0x4e,0x4f,0xb0,0x89,0x67,0x14,0x72,0x00,
	0x70,0xf5,0x4e,0x4f,0x43,0xfa,0x02,0x3a,
	0x72,0x2b,0x70,0x80,0x4e,0x4f,0x21,0xc0,
	0x0c,0xee,0x72,0x24,0x70,0xf5,0x4e,0x4f,
	0x4a,0x80,0x67,0x1c,0x0c,0x00,0x00,0x02,
	0x66,0x14,0x43,0xf8,0x20,0x00,0x76,0x03,
	0x72,0x2c,0x70,0xf5,0x4e,0x4f,0x4a,0x80,
	0x66,0x04,0x51,0xce,0xff,0xde,0x4e,0x75,
	0x72,0x2b,0x70,0xf5,0x4e,0x4f,0x4a,0x80,
	0x66,0x50,0x43,0xf8,0x20,0x00,0x72,0x25,
	0x70,0xf5,0x4e,0x4f,0x4a,0x80,0x66,0x42,
	0x0c,0xa9,0x00,0x00,0x02,0x00,0x00,0x04,
	0x66,0x38,0x74,0x00,0x76,0x02,0x7a,0x01,
	0x72,0x26,0x70,0xf5,0x4e,0x4f,0x4a,0x80,
	0x66,0x28,0x0c,0x91,0x58,0x36,0x38,0x53,
	0x66,0x20,0x0c,0xa9,0x43,0x53,0x49,0x31,
	0x00,0x04,0x66,0x16,0x74,0x02,0x76,0x02,
	0x72,0x26,0x70,0xf5,0x4e,0x4f,0x4a,0x80,
	0x66,0x08,0x0c,0x11,0x00,0x60,0x66,0x02,
	0x4e,0x91,0x4e,0x75,0x48,0xe7,0xdf,0xfe,
	0x70,0x8e,0x4e,0x4f,0x02,0x80,0x00,0xff,
	0xff,0xff,0x7e,0xff,0x0c,0x80,0x00,0xea,
	0x00,0x00,0x65,0x1c,0x0c,0x80,0x00,0xea,
	0x00,0x24,0x64,0x14,0x0c,0x80,0x00,0xea,
	0x00,0x20,0x67,0x3e,0x7e,0x00,0x1e,0x00,
	0xe4,0x0f,0x02,0x07,0x00,0x07,0x60,0x32,
	0x4a,0x02,0x66,0x2e,0x2f,0x09,0x43,0xfa,
	0x01,0xf2,0x43,0xe9,0x01,0x38,0x22,0x3c,
	0x00,0x00,0x01,0xf5,0x70,0x80,0x4e,0x4f,
	0xb0,0x89,0x67,0x14,0x72,0x00,0x70,0xf5,
	0x4e,0x4f,0x43,0xfa,0x01,0x54,0x72,0x2b,
	0x70,0x80,0x4e,0x4f,0x21,0xc0,0x0c,0xee,
	0x22,0x5f,0x0c,0x02,0x00,0x07,0x64,0x00,
	0x00,0xfe,0x78,0x00,0x18,0x02,0x7a,0x03,
	0x72,0x24,0x70,0xf5,0x4e,0x4f,0x4a,0x80,
	0x67,0x1e,0x0c,0x00,0x00,0x02,0x66,0x00,
	0x00,0xe0,0x76,0x03,0x72,0x2c,0x70,0xf5,
	0x4e,0x4f,0x4a,0x80,0x66,0x00,0x00,0xd2,
	0x51,0xcd,0xff,0xde,0x60,0x00,0x00,0xca,
	0x72,0x25,0x70,0xf5,0x4e,0x4f,0x4a,0x80,
	0x66,0x00,0x00,0xbe,0x0c,0xa9,0x00,0x00,
	0x02,0x00,0x00,0x04,0x66,0x00,0x00,0xb2,
	0x2c,0x02,0x74,0x04,0x76,0x02,0x7a,0x01,
	0x72,0x26,0x70,0xf5,0x4e,0x4f,0x24,0x06,
	0x4a,0x80,0x66,0x00,0x00,0x9c,0x0c,0x91,
	0x58,0x36,0x38,0x4b,0x66,0x00,0x00,0x92,
	0x48,0x42,0xb8,0x07,0x62,0x14,0x67,0x0a,
	0x72,0xff,0x61,0x00,0x00,0x92,0xd4,0x43,
	0x60,0x08,0x72,0x00,0x61,0x00,0x00,0x88,
	0xd4,0x43,0x48,0x42,0x2c,0x02,0x74,0x00,
	0x76,0x02,0x7a,0x01,0x72,0x26,0x70,0xf5,
	0x4e,0x4f,0x24,0x06,0x4a,0x80,0x66,0x60,
	0x0c,0x91,0x58,0x36,0x38,0x53,0x66,0x58,
	0x0c,0xa9,0x43,0x53,0x49,0x31,0x00,0x04,
	0x66,0x4e,0x74,0x06,0x76,0x1a,0x72,0x26,
	0x70,0xf5,0x4e,0x4f,0x24,0x06,0x4a,0x80,
	0x66,0x3e,0x0c,0xa9,0x01,0x53,0x43,0x48,
	0x00,0x0e,0x66,0x34,0x0c,0xa9,0x44,0x49,
	0x53,0x4b,0x00,0x12,0x66,0x2a,0x20,0x09,
	0xd1,0xa9,0x00,0x06,0xd1,0xa9,0x00,0x0a,
	0x20,0x11,0x52,0x80,0x67,0x0a,0x20,0x11,
	0xd0,0x89,0x22,0x80,0x22,0x40,0x60,0xd2,
	0x48,0x42,0x13,0x42,0x00,0x16,0x48,0x42,
	0x4c,0xdf,0x7f,0xfb,0x52,0x82,0x4e,0x75,
	0x52,0x82,0x60,0x00,0xfe,0xfe,0x4c,0xdf,
	0x7f,0xfb,0x74,0xff,0x4e,0x75,0x48,0xe7,
	0x20,0x40,0x74,0x0e,0x76,0x00,0x43,0xe9,
	0x00,0x10,0x4a,0x11,0x67,0x20,0x0c,0x91,
	0x48,0x75,0x6d,0x61,0x66,0x18,0x0c,0xa9,
	0x6e,0x36,0x38,0x6b,0x00,0x04,0x66,0x0e,
	0x10,0x29,0x00,0x08,0xe2,0x08,0x65,0x06,
	0x52,0x83,0x80,0x01,0x67,0x04,0x51,0xca,
	0xff,0xd6,0x4c,0xdf,0x02,0x04,0x4e,0x75,
	0x48,0xe7,0xff,0xfe,0xe2,0x08,0x65,0x20,
	0x30,0x38,0x0a,0x0e,0x0c,0x40,0x00,0x40,
	0x65,0x0c,0x0c,0x40,0x00,0x50,0x65,0x10,
	0x0c,0x40,0x00,0xf5,0x67,0x0a,0x4c,0xdf,
	0x7f,0xff,0x2f,0x38,0x0c,0xee,0x4e,0x75,
	0x4c,0xdf,0x7f,0xff,0x4e,0x73,0x20,0x53,
	0x43,0x53,0x49,0x2d,0x49,0x4f,0x43,0x53,
	0x20,0x62,0x69,0x6e,0x61,0x72,0x79,0x20,
	0x66,0x72,0x6f,0x6d,0x20,0x46,0x4f,0x52,
	0x4d,0x41,0x54,0x2e,0x78,0x20,0x43,0x6f,
	0x70,0x79,0x72,0x69,0x67,0x68,0x74,0x20,
	0x28,0x43,0x29,0x20,0x31,0x39,0x39,0x30,
	0x2d,0x31,0x39,0x39,0x33,0x20,0x53,0x48,
	0x41,0x52,0x50,0x2f,0x46,0x69,0x72,0x73,
	0x74,0x20,0x43,0x6c,0x61,0x73,0x73,0x20,
	0x54,0x65,0x63,0x68,0x6e,0x6f,0x6c,0x6f,
	0x67,0x79
};
