//---------------------------------------------------------------------------
//
//	X68000 EMULATOR "XM6" UTILITY
//
//	Copyright (C) 2001-2006 ohD(ytanaka@ipc-tokai.or.jp)
//	[ TrueKey ]
//
//---------------------------------------------------------------------------

#include "os.h"
#include "xm6util.h"
#include "truekey.h"

#if defined(_WIN32)

//===========================================================================
//
//	TrueKey
//
//===========================================================================

//---------------------------------------------------------------------------
//
//	RXgN^
//
//---------------------------------------------------------------------------
TrueKey::TrueKey()
{
	m_pBuf = NULL;
	m_dwSize = 0;
}

//---------------------------------------------------------------------------
//
//	fXgN^
//
//---------------------------------------------------------------------------
TrueKey::~TrueKey()
{
	ASSERT(!m_pBuf);
}

//---------------------------------------------------------------------------
//
//	
//
//---------------------------------------------------------------------------
BOOL TrueKey::Init()
{
	ASSERT(this);
	ASSERT(!m_pBuf);
	ASSERT(m_dwSize == 0);

	// m
	try {
		m_pBuf = new BYTE[ BitmapMax];
	}
	catch (...) {
		m_pBuf = NULL;
	}
	if (!m_pBuf) {
		return FALSE;
	}

	// WJ
	m_dwSize = Extract(CompressData, m_pBuf, sizeof(CompressData));
	ASSERT(m_dwSize != 0);

	return TRUE;
}

//---------------------------------------------------------------------------
//
//	N[Abv
//
//---------------------------------------------------------------------------
void TrueKey::Cleanup()
{
	// 
	if (m_pBuf) {
		delete[] m_pBuf;
		m_pBuf = NULL;
	}
}

//---------------------------------------------------------------------------
//
//	WJ
//
//---------------------------------------------------------------------------
DWORD FASTCALL TrueKey::Extract(const BYTE *pSrc, BYTE *pDst, DWORD dwSrc)
{
	DWORD dwFlags;
	DWORD dwData;
	DWORD dwDst;
	DWORD dwTemp;
	int nCurrent;
	int nFrom;
	int nCopy;

	ASSERT(this);
	ASSERT(pSrc);
	ASSERT(pDst);
	ASSERT(dwSrc != 0);

	// NA
	memset(m_byDic, 0, sizeof(m_byDic));

	// f[^擪'LZP'+EOFA`FbN
	if (pSrc[0] != 'L') {
		return 0;
	}
	if (pSrc[1] != 'Z') {
		return 0;
	}
	if (pSrc[2] != 'P') {
		return 0;
	}
	if (pSrc[3] != 0x1a) {
		return 0;
	}
	pSrc += 4;

	// TCYݒAtOEJgʒu
	dwSrc -= 4;
	dwFlags = 0;
	nCurrent = 0x1000 - 18;

	// o̓TCY0
	dwDst = 0;

	// [v
	while (dwSrc != 0) {
		ASSERT((nCurrent >= 0) && (nCurrent < 0x1000));

		// tOVtg
		dwFlags >>= 1;

		// tOL`FbN
		if ((dwFlags & 0x0100) == 0) {
			// tOȂ̂ŁAVĂ
			if (dwSrc == 0) {
				break;
			}
			dwFlags = (DWORD)*pSrc++;
			dwSrc--;

			// 0x0000ff00OR (̃`FbNQ)
			dwFlags |= 0x0000ff00;
		}

		// tO^Cv`FbN
		if (dwFlags & 1) {
			ASSERT(dwSrc != 0);
			dwData = (DWORD)*pSrc++;
			dwSrc--;

			// o
			*pDst++ = (BYTE)dwData;
			dwDst++;

			// ֊i[
			m_byDic[nCurrent] = (BYTE)dwData;
			nCurrent = (nCurrent + 1) & (0x1000 - 1);
			continue;
		}

		// Rs[^Cv
		ASSERT(dwSrc != 0);
		dwData = (DWORD)*pSrc++;
		dwSrc--;
		ASSERT(dwSrc != 0);
		dwTemp = (DWORD)*pSrc++;
		dwSrc--;

		// Rs[ARs[񐔂擾
		nFrom = (int)((dwTemp << 4) & 0x0f00);
		nFrom |= (int)dwData;
		nCopy = (int)((dwTemp & 0x0f) + 3);

		// Rs[
		while (nCopy > 0) {
			// o
			dwData = (DWORD)m_byDic[nFrom];
			nFrom = (nFrom + 1) & (0x1000 - 1);
			*pDst++ = (BYTE)dwData;
			dwDst++;

			// ֊i[
			m_byDic[nCurrent] = (BYTE)dwData;
			nCurrent = (nCurrent + 1) & (0x1000 - 1);

			// 
			nCopy--;
		}
	}

	return dwDst;
}

//---------------------------------------------------------------------------
//
//	擾
//
//---------------------------------------------------------------------------
int FASTCALL TrueKey::GetWidth() const
{
	BITMAPINFOHEADER *pbmi;

	ASSERT(this);

	// Ó`FbN
	if (!IsValid()) {
		return 0;
	}

	pbmi = (BITMAPINFOHEADER*)&m_pBuf[sizeof(BITMAPFILEHEADER)];
	return pbmi->biWidth;
}

//---------------------------------------------------------------------------
//
//	擾
//
//---------------------------------------------------------------------------
int FASTCALL TrueKey::GetHeight() const
{
	BITMAPINFOHEADER *pbmi;

	// Ó`FbN
	if (!IsValid()) {
		return 0;
	}

	pbmi = (BITMAPINFOHEADER*)&m_pBuf[sizeof(BITMAPFILEHEADER)];
	return pbmi->biHeight;
}

//---------------------------------------------------------------------------
//
//	rbgJEg擾
//
//---------------------------------------------------------------------------
int FASTCALL TrueKey::GetBitCount() const
{
	BITMAPINFOHEADER *pbmi;

	ASSERT(this);

	// Ó`FbN
	if (!IsValid()) {
		return 0;
	}

	pbmi = (BITMAPINFOHEADER*)&m_pBuf[sizeof(BITMAPFILEHEADER)];
	return pbmi->biBitCount;
}

//---------------------------------------------------------------------------
//
//	rbgf[^擾
//
//---------------------------------------------------------------------------
const BYTE* FASTCALL TrueKey::GetBits() const
{
	BITMAPFILEHEADER *pbmf;

	ASSERT(this);

	// Ó`FbN
	if (!IsValid()) {
		return NULL;
	}

	pbmf = (BITMAPFILEHEADER*)&m_pBuf[0];
	return &m_pBuf[pbmf->bfOffBits];
}

//---------------------------------------------------------------------------
//
//	Ó`FbN
//	擪'B''M'A`FbN
//
//---------------------------------------------------------------------------
BOOL FASTCALL TrueKey::IsValid() const
{
	ASSERT(this);

	// obt@邩
	if (!m_pBuf) {
		return FALSE;
	}

	// BMŎn܂Ă邩
	if (m_pBuf[0] != 'B') {
		return FALSE;
	}
	if (m_pBuf[1] != 'M') {
		return FALSE;
	}

	// OK
	return TRUE;
}

//---------------------------------------------------------------------------
//
//	kf[^(LZP`)
//
//---------------------------------------------------------------------------
const BYTE TrueKey::CompressData[] = {
	0x4c,0x5a,0x50,0x1a,0xaf,0x42,0x4d,0x3e,
	0xc8,0xe8,0xf3,0x3e,0xeb,0xf0,0x28,0xf6,
	0xeb,0xf0,0x20,0x03,0xeb,0xf0,0x02,0x00,
	0x00,0x01,0x70,0x07,0x00,0xe9,0xf2,0xf1,
	0xf4,0xde,0xfd,0xff,0xff,0xff,0x27,0x01,
	0x00,0x2e,0x0f,0x40,0x0f,0x52,0x0f,0x64,
	0x0f,0x76,0x0f,0x88,0x0f,0x9a,0x0f,0xac,
	0x0f,0x00,0xbe,0x0f,0xd0,0x0f,0xe2,0x0f,
	0xf4,0x0f,0x06,0x1f,0x18,0x1f,0x2a,0x1f,
	0x3c,0x1f,0x20,0x4e,0x1f,0x60,0x1f,0x72,
	0x1f,0x84,0x1f,0x96,0x1e,0x7f,0x96,0x1f,
	0xba,0x1f,0x00,0xcc,0x1f,0xde,0x1f,0xf0,
	0x1f,0x9f,0x1f,0x14,0x2f,0x26,0x2f,0x38,
	0x2f,0x4a,0x2f,0x00,0x5c,0x2f,0x0b,0x2f,
	0x80,0x2f,0x92,0x2f,0xa4,0x2f,0xb6,0x2f,
	0x65,0x2f,0xda,0x2f,0x00,0xec,0x2f,0xfe,
	0x2f,0x10,0x3f,0x22,0x3f,0xd1,0x2f,0x46,
	0x3f,0x58,0x3f,0x6a,0x3f,0x00,0x7c,0x3f,
	0x2b,0x3f,0xa0,0x3f,0xb2,0x3f,0xc4,0x3f,
	0xd6,0x3f,0xe8,0x3f,0x97,0x3f,0x00,0x0c,
	0x4f,0x1e,0x4f,0x30,0x4f,0x42,0x4f,0xf1,
	0x3f,0x66,0x4f,0x78,0x4f,0x8a,0x4f,0x00,
	0x9c,0x4f,0xae,0x4f,0x5d,0x4f,0xd2,0x4f,
	0xe4,0x4f,0xf6,0x4f,0x08,0x5f,0xb7,0x4f,
	0x00,0x1a,0x5f,0x3e,0x5f,0x50,0x5f,0x62,
	0x5f,0x74,0x5f,0x23,0x5f,0x98,0x5f,0xaa,
	0x5f,0x00,0xbc,0x5f,0xce,0x5f,0xe0,0x5f,
	0x8f,0x5f,0x04,0x6f,0x16,0x6f,0x28,0x6f,
	0x3a,0x6f,0x00,0xe9,0x5f,0x5e,0x6f,0x70,
	0x6f,0x82,0x6f,0x94,0x6f,0xa6,0x6f,0x55,
	0x6f,0xca,0x6f,0x00,0xdc,0x6f,0xee,0x6f,
	0x00,0x7f,0xaf,0x6f,0x24,0x7f,0x36,0x7f,
	0x48,0x7f,0x5a,0x7f,0x00,0x6c,0x7f,0x1b,
	0x7f,0x90,0x7f,0xa2,0x7f,0xb4,0x7f,0xc6,
	0x7f,0x75,0x7f,0xea,0x7f,0x00,0xfc,0x7f,
	0x0e,0x8f,0x20,0x8f,0x32,0x8f,0xe1,0x7f,
	0x56,0x8f,0x68,0x8f,0x7a,0x8f,0x00,0x8c,
	0x8f,0x3b,0x8f,0x9e,0x8f,0xc2,0x8f,0xd4,
	0x8f,0xe6,0x8f,0xf8,0x8f,0xa7,0x8f,0xc0,
	0x1c,0x9f,0x2e,0x9f,0x40,0x9f,0x52,0x9f,
	0x64,0x9f,0x13,0x91,0xf7,0xff,0x07,0xf2,
	0xba,0x3f,0x66,0x9f,0x91,0x9f,0xa3,0x9f,
	0xb5,0x9f,0xc7,0x9f,0x0e,0x76,0x94,0xec,
	0xb2,0xdf,0xca,0x9f,0xf5,0x9f,0x07,0xaf,
	0x19,0xaf,0x7c,0x2b,0xaf,0x12,0x92,0x83,
	0xff,0xee,0xb2,0xef,0x2e,0xaf,0xe0,0x59,
	0xaf,0x6b,0xaf,0x7d,0xaf,0x8f,0xaf,0x12,
	0x92,0xb7,0xff,0xec,0x09,0xaa,0x47,0xaf,
	0xb4,0xa6,0xbf,0xb4,0xaf,0xd8,0xaf,0xea,
	0xaf,0x09,0x9b,0x07,0xd7,0xff,0xef,0xaa,
	0xaf,0xbc,0xaf,0x31,0xbf,0x43,0xbf,0x55,
	0xbf,0xfc,0x04,0xbf,0x75,0xba,0xf6,0xda,
	0xed,0xf8,0x71,0x7b,0x1f,0xfb,0x87,0x5d,
	0xfe,0xbe,0x75,0xbf,0xa3,0xbf,0xb5,0xbf,
	0x9e,0x0c,0x98,0xe7,0xff,0xee,0x9a,0x73,
	0xbf,0x85,0xb2,0xfb,0x7f,0xbb,0x73,0xfb,
	0xbb,0x5d,0xfd,0xbf,0x14,0x9f,0x20,0x07,
	0xcf,0x19,0xcf,0xc8,0xbc,0xe3,0x9f,0xe9,
	0xb3,0xdb,0xf0,0xbf,0x65,0xcf,0xcc,0x77,
	0xcf,0xce,0x9f,0xff,0xf1,0x7e,0x9f,0x4c,
	0xc5,0x6b,0xfd,0x0f,0xbb,0x5d,0xfb,0xbf,
	0x2a,0xbf,0xcf,0xcf,0xe1,0xcf,0x0c,0x9f,
	0xfe,0x05,0xde,0xf2,0x5a,0x6d,0xfb,0xdb,
	0x5b,0xfd,0x0f,0xbb,0x4d,0xfb,0x87,0xbe,
	0xcf,0x33,0xdf,0x45,0xdf,0xf4,0xcf,0x6e,
	0x69,0xde,0xf4,0xba,0x9d,0x1a,0xd1,0x87,
	0x53,0xbc,0xcf,0xe0,0x95,0xdf,0xa7,0xdf,
	0x56,0xdf,0xcb,0xdf,0xd0,0xd1,0xfb,0xdb,
	0x3b,0xc1,0xfe,0xe0,0xd0,0x85,0xdf,0xfa,
	0xdf,0x0c,0xef,0xbb,0xd9,0xcf,0xff,0x27,
	0xe3,0xbb,0xbb,0xea,0xdf,0xde,0xd2,0xbb,
	0xe4,0xd1,0x58,0xcf,0x78,0x5d,0xef,0x6f,
	0xef,0x9a,0xac,0xed,0xbb,0xbb,0xbb,0x7a,
	0xef,0xf7,0xff,0xfb,0xfd,0x8a,0xb0,0xe0,
	0xff,0x7f,0xfd,0xe1,0x83,0x4e,0xef,0xc3,
	0xef,0xd5,0xef,0x9c,0xaa,0xee,0x83,0xb8,
	0x09,0x3b,0xde,0xef,0x02,0xf6,0xfe,0xe5,
	0xd0,0x17,0xff,0x29,0xff,0x3b,0xff,0x02,
	0x72,0x98,0xee,0x92,0xef,0x65,0xf8,0x3b,
	0xcf,0x88,0xff,0x9a,0xff,0x1d,0xed,0x0f,
	0xee,0xd7,0xbd,0x60,0xa6,0xff,0xc9,0xf5,
	0xd7,0xbf,0xec,0xff,0xdc,0xfe,0xff,0x49,
	0xfe,0xd7,0xbd,0x7b,0x0a,0x0e,0xfd,0xe3,
	0xff,0xf7,0xd1,0xc7,0x1b,0xb1,0xfd,0xd8,
	0xf7,0x0f,0x0e,0x38,0x5e,0x1f,0x0a,0x0f,
	0x55,0x0f,0x67,0x0f,0xea,0xe9,0xfc,0x22,
	0x0f,0x4a,0xe0,0xdd,0xfb,0xae,0xba,0xed,
	0x6e,0x3f,0xfd,0xb7,0x77,0x75,0xd7,0x5d,
	0x77,0xff,0xb8,0x0f,0x9c,0xca,0x0f,0x85,
	0xea,0xef,0xbe,0xfb,0x89,0x0f,0x9b,0x01,
	0xee,0x0f,0xee,0xfd,0x77,0xeb,0xa4,0x0f,
	0x19,0x1f,0x2b,0x1f,0x1e,0xed,0x7b,0xee,
	0x0e,0x36,0x1f,0xfd,0xdd,0xfd,0x6e,0x02,
	0x11,0x0f,0x70,0x6b,0x75,0xd8,0x0a,0x1f,
	0x7f,0x1f,0x91,0x1f,0xbc,0xdf,0xfe,0x52,
	0x1f,0xfe,0xee,0xc6,0xed,0x6e,0xfc,0xf7,
	0x0f,0x5d,0x75,0xdf,0x4d,0x6f,0x1f,0xe4,
	0x1f,0xf6,0x1f,0xa5,0x1f,0xfe,0x27,0x0e,
	0xfd,0x61,0xba,0xeb,0xae,0xfc,0xf8,0x0f,
	0xdd,0x0e,0x38,0xd6,0x43,0x0f,0x48,0x2f,
	0x5a,0x2f,0x09,0x2f,0xfe,0x27,0x0d,0xff,
	0xfb,0xaf,0xba,0xef,0xee,0xfd,0xd9,0x7f,
	0x73,0x21,0xd3,0x18,0xfe,0x00,0xa7,0x27,
	0xff,0xf0,0x48,0x9f,0xcf,0xc5,0x2f,0x74,
	0x20,0x87,0x2c,0xef,0x8a,0x24,0xb6,0x92,
	0x21,0x21,0xbf,0x97,0x2f,0xa9,0x2f,0x1e,
	0x3f,0x69,0x2b,0xbf,0x90,0xe1,0xe0,0x2f,
	0xff,0xe0,0x3f,0xf7,0xd9,0xc7,0x1f,0xf1,
	0xfd,0x89,0xdf,0xfb,0x2d,0x74,0x27,0xfc,
	0x2a,0x3f,0x8b,0x3f,0x72,0x22,0xdf,0x00,
	0xf4,0xe1,0x18,0x3f,0xb9,0x3f,0x68,0x3f,
	0xc0,0x3f,0xef,0x3f,0x9e,0x35,0x42,0x3f,
	0x18,0x1b,0x4f,0xca,0x3f,0xdc,0x30,0xc0,
	0x07,0x24,0x4f,0xf3,0x3f,0xd9,0xf1,0x02,
	0xbd,0xf0,0x61,0x56,0x4f,0x82,0x4f,0x31,
	0x4f,0x43,0x4f,0xb8,0x4f,0x1b,0x06,0x00,
	0x74,0x2f,0xe5,0x4f,0x94,0x4f,0xec,0x4f,
	0x1b,0x5f,0x7e,0x07,0xd4,0x4f,0x49,0x5f,
	0x80,0xf8,0x4f,0x50,0x5f,0x7f,0x5f,0xe2,
	0x07,0x82,0x5f,0xad,0x5f,0x5c,0x5f,0xfe,
	0x03,0x00,0x01,0xb4,0x5f,0x83,0x5f,0x49,
	0x1f,0x0a,0x6f,0xb9,0x5f,0xcb,0x5f,0x00,
	0x40,0x6f,0x6b,0x2f,0x64,0x6f,0x76,0x6f,
	0x5d,0x5f,0x6d,0x5f,0xac,0x6f,0x5b,0x6f,
	0x00,0xd0,0x6f,0x7f,0x6f,0x91,0x6f,0x06,
	0x7f,0xb5,0x6f,0x2a,0x7f,0x3c,0x7f,0xeb,
	0x6b,0x63,0xfc,0x0f,0xfb,0x6f,0x70,0x7f,
	0x63,0x47,0xff,0xcf,0x0c,0x4f,0x60,0xa0,
	0x7f,0x4f,0x7f,0x61,0x7f,0xd6,0x7f,0x65,
	0x45,0xfb,0xb7,0x8f,0x7f,0x00,0x04,0x8f,
	0xeb,0x6f,0xc5,0x7f,0x3a,0x8f,0xe9,0x7f,
	0x5e,0x8f,0x0d,0x8f,0x1f,0x8f,0x1c,0x94,
	0x8f,0x43,0x8f,0xfb,0xf7,0x5f,0xa2,0x8f,
	0xcd,0x8f,0x7c,0x8a,0x61,0xe0,0x38,0x60,
	0x8d,0x8f,0x02,0x9f,0x65,0x45,0xe0,0xb7,
	0xbb,0x8f,0x20,0x30,0x9f,0xdf,0x8f,0xf1,
	0x8f,0x66,0x9f,0x4d,0x86,0x8f,0x1f,0x9f,
	0x94,0x9f,0x10,0x7b,0x8f,0x55,0x9f,0xca,
	0x9f,0x4d,0x86,0xbe,0xdb,0xff,0xf8,0x9f,
	0xa7,0x9f,0x10,0xb9,0x9f,0x2e,0xaf,0x25,
	0xe5,0xe5,0x9f,0xff,0x0b,0x37,0xa8,0x3d,
	0x62,0x54,0x47,0x80,0x00,0x7f,0x1c,0xaf,
	0x91,0xaf,0x84,0x77,0x86,0x4b,0xaf,0x04,
	0x5d,0xaf,0x6f,0xaf,0xfc,0x14,0x30,0xe8,
	0xaf,0x97,0xaf,0xfa,0xaf,0x12,0xb2,0x00,
	0xa8,0x37,0xca,0xaf,0x1e,0xb6,0xe5,0xaf,
	0x86,0x27,0x01,0xbf,0x13,0xbf,0x7f,0xbf,
	0x00,0x37,0xbf,0x83,0xaf,0x5b,0xbf,0x6d,
	0xb7,0x37,0x2e,0x88,0xbf,0x9a,0xbf,0xac,
	0xbf,0xfe,0x14,0xc1,0xf0,0xff,0xc3,0x94,
	0x3f,0x9c,0x3a,0xf7,0xef,0xf5,0xf7,0x68,
	0xb7,0xef,0xee,0xef,0xf1,0x07,0xee,0xeb,
	0xb2,0xe7,0x9c,0xec,0xbf,0xb2,0x7d,0x0e,
	0xcf,0x78,0xc3,0xff,0xf7,0x7f,0xbd,0x65,
	0xdf,0x6d,0xda,0xef,0x79,0xed,0xec,0x06,
	0x38,0xc2,0xee,0xef,0x1b,0xad,0x41,0xcf,
	0x74,0x53,0xcf,0x0d,0xa9,0xf0,0x70,0xb0,
	0xfc,0xfb,0xc7,0x78,0xcf,0xbf,0xf7,0xbf,
	0xbd,0x75,0xdf,0xf5,0x90,0xcf,0xee,0x51,
	0xfb,0xa4,0xcf,0x10,0xdf,0x0c,0xaa,0xf8,
	0x46,0xb1,0xfb,0x5c,0xff,0xfe,0xed,0xc0,
	0xfd,0x75,0xdf,0x85,0xda,0xef,0xdd,0x3c,
	0xc7,0xb6,0x38,0xc2,0xfd,0xef,0x3b,0xb1,
	0x09,0xdf,0x1b,0xdf,0xf8,0xb5,0x7e,0x3e,
	0xdf,0xcd,0x40,0xa0,0xe3,0x75,0xdf,0x75,
	0xef,0xda,0x6f,0xdc,0x3d,0x68,0xb7,0xe1,
	0xee,0xef,0x47,0xfb,0xee,0xdb,0x08,0xdf,
	0xd8,0xdf,0x0c,0xab,0x03,0xd7,0xc1,0xfc,
	0xec,0x0f,0xed,0xc0,0xdf,0x74,0x3f,0x74,
	0x3a,0x9f,0xfe,0x5a,0xd9,0xee,0xee,0x1f,
	0xf7,0xef,0x28,0x73,0xc8,0xd1,0xdf,0xe3,
	0xdf,0x0d,0xaa,0xc3,0x9f,0xdf,0xe9,0xc4,
	0xbf,0xfd,0x2f,0xff,0x77,0xff,0xff,0x22,
	0xea,0xff,0x91,0xe1,0xda,0xfd,0x08,0x44,
	0xef,0xf2,0xdf,0xd8,0xc0,0x87,0x6c,0xef,
	0x8a,0xc0,0x81,0xe2,0x92,0xc9,0x01,0xee,
	0x6b,0x40,0xe7,0x90,0x99,0xef,0xab,0xef,
	0x91,0xdf,0x57,0x8f,0x25,0xc1,0x7f,0xfd,
	0xff,0x8f,0xfb,0xff,0xec,0x1b,0xc0,0xd8,
	0xc7,0xef,0xff,0xf1,0xfa,0xef,0x0c,0xff,
	0x2a,0xdf,0xff,0xfc,0x01,0xe3,0x33,0xff,
	0x49,0xd7,0x2f,0xc8,0xbd,0xff,0x6c,0xff,
	0x7e,0xff,0xd4,0xc4,0x01,0x83,0xc2,0xff,
	0x0d,0x0f,0xbc,0xff,0xce,0xff,0xe0,0xff,
	0x6a,0x51,0x37,0x20,0x98,0x75,0xcf,0x6e,
	0x0f,0x1d,0x04,0xdf,0xe7,0x97,0xf0,0xd3,
	0x1c,0x3f,0x07,0xff,0xf8,0xf9,0x3c,0x0f,
	0x5e,0x59,0xa8,0x40,0x5d,0x0f,0x28,0x21,
	0xff,0xfb,0xe8,0x60,0xc6,0x0e,0x3f,0xe3,
	0xe3,0xfb,0xdf,0x5d,0x19,0x05,0x1c,0x61,
	0xff,0xbe,0xfb,0xf3,0xbf,0x1f,0xf9,0xe1,
	0xab,0x09,0x1f,0xff,0xf7,0x79,0x24,0x60,
	0x50,0xc2,0x70,0x3e,0xa7,0x0f,0xc3,0x00,
	0xcf,0x65,0xe2,0xc3,0x0f,0xfe,0xc5,0x10,
	0xfb,0xd7,0xaf,0xba,0xfd,0xdf,0xdd,0x77,
	0xdd,0xdb,0x6b,0x27,0x14,0x7e,0xeb,0xae,
	0xeb,0x00,0x31,0x86,0x3a,0xc0,0x27,0x1a,
	0xc1,0x70,0x77,0x76,0x60,0x50,0x27,0x10,
	0x8c,0x0a,0x1f,0x27,0x11,0x8f,0xff,0xfb,
	0xf0,0x25,0x1f,0x37,0x13,0xb7,0x3f,0xbb,
	0x7b,0xef,0xbe,0xbe,0xdb,0x83,0xe0,0x47,
	0x16,0x9f,0x7e,0xf5,0xba,0xff,0xe0,0x2f,
	0xc6,0x06,0x34,0x1f,0x21,0x7f,0x67,0x10,
	0x1f,0x01,0x6e,0x1f,0x8b,0x11,0x0f,0x06,
	0x11,0x89,0x1f,0x5e,0x9b,0x12,0xbf,0xbb,
	0xfb,0xbb,0xa4,0x10,0xd5,0xa8,0x16,0xdb,
	0xef,0x6e,0xb3,0x11,0x0f,0xee,0xb9,0x1d,
	0x1c,0x17,0x80,0xcb,0x11,0x97,0xf0,0xd2,
	0x1f,0xbe,0x72,0x39,0xd2,0xef,0x1f,0x9c,
	0x10,0xf8,0xff,0x3c,0x7d,0xe7,0xdb,0xff,
	0xbf,0xbe,0xd5,0x96,0x44,0x16,0xee,0xe1,
	0x77,0x20,0xba,0x2d,0xc8,0xbc,0x75,0x70,
	0x31,0xef,0x60,0x33,0x36,0x2f,0x36,0xd1,
	0x4f,0xf0,0x6a,0x5f,0xd0,0x05,0xcf,0xdb,
	0xfe,0xfb,0xeb,0x6c,0x21,0xe0,0x05,0x7e,
	0xed,0x4d,0xee,0x77,0x20,0x87,0x1f,0x80,
	0x2c,0xff,0x00,0x77,0x93,0x21,0xc8,0xe7,
	0x90,0x9a,0x2f,0x53,0x31,0xcf,0x4d,0x2f,
	0xc1,0xb5,0xfb,0xd7,0x17,0xee,0xba,0xeb,
	0xa4,0x10,0xce,0x20,0x05,0xb0,0x12,0x1b,
	0x30,0xc8,0x80,0x2c,0x87,0xc1,0x93,0x20,
	0xfe,0xfb,0x2f,0x61,0x53,0xc3,0xcf,0x1c,
	0xe9,0x1f,0x27,0x37,0xae,0xba,0xed,0x40,
	0x10,0x37,0x3a,0x9b,0x51,0x5d,0xfb,0xe7,
	0x9e,0xf0,0x5f,0xbf,0x5d,0x32,0x38,0x63,
	0x3f,0xcf,0xff,0xff,0x87,0xcf,0x85,0x1f,
	0xe3,0x33,0xe0,0x3f,0x9f,0xf8,0x38,0x71,
	0xc7,0x1e,0xdc,0x01,0x38,0x36,0xec,0x07,
	0x61,0xff,0xb8,0xa6,0x00,0xac,0x3f,0xd6,
	0xb5,0x62,0x3f,0xfd,0x01,0x80,0xdc,0x3f,
	0x51,0x4f,0x7c,0x0a,0x5a,0x41,0x8d,0x0c,
	0x2e,0x0f,0x0a,0xa9,0xfc,0x83,0x3f,0xcf,
	0xbd,0x0f,0xb6,0x4f,0x19,0x0f,0xda,0x4f,
	0x7a,0xa1,0x07,0x0c,0x8e,0x4f,0x37,0xd0,
	0x7f,0xcf,0xda,0xb1,0xa9,0x4f,0x1e,0x5f,
	0xcd,0x4f,0x12,0x36,0xfe,0x7f,0x39,0xd1,
	0xc9,0x3e,0xe1,0x46,0xa0,0x16,0x3f,0x7f,
	0x5f,0x20,0x2e,0x5f,0xa3,0x5f,0x83,0x10,
	0xa5,0x41,0xc9,0x3e,0xc3,0x6b,0x5f,0xe0,
	0x5f,0xe8,0x8f,0x5f,0x04,0x6f,0x0f,0xa4,
	0x39,0x0b,0x6e,0xfe,0x0f,0x0f,0x03,0xff,
	0xcf,0xc1,0x73,0x3a,0x6f,0x4c,0x6f,0xfb,
	0x5f,0x6c,0x6a,0x9f,0x01,0x7d,0x3e,0x60,
	0x6c,0xfe,0x7f,0xfc,0xe4,0x1f,0x33,0x60,
	0x50,0xa6,0x4f,0xab,0x6f,0x5a,0x6f,0xcf,
	0x6f,0xe7,0x35,0x01,0x9f,0x19,0xa2,0x7e,
	0xc0,0xa7,0x00,0x01,0xf0,0x3f,0xff,0xc0,
	0xed,0x68,0x40,0xc0,0xa3,0xdb,0xbe,0xbb,
	0x6f,0x30,0x7f,0x34,0x70,0xe7,0x61,0x3f,
	0xe2,0x61,0x82,0xeb,0x6c,0x7f,0xfb,0x6f,
	0x0d,0x7f,0x1f,0x7f,0x94,0x7f,0x89,0x74,
	0x3f,0xfc,0x07,0xe2,0x9d,0x67,0xfe,0x7f,
	0xfd,0xe4,0x3f,0xff,0x03,0xcf,0xf8,0x9a,
	0x6d,0xe7,0x62,0xda,0x7f,0x89,0x7f,0x0c,
	0x6c,0x34,0x02,0x0c,0xc7,0xb2,0xb4,0x79,
	0xfc,0xce,0x32,0x6f,0xd4,0x7f,0xe6,0x7f,
	0x5b,0x8f,0xfc,0x0a,0x8f,0x0d,0xa3,0x7e,
	0x7f,0xfe,0x1f,0x87,0xff,0x1d,0xcf,0xff,
	0x00,0xff,0xfc,0xf8,0x2f,0x8f,0xa4,0x8f,
	0x53,0x8f,0x4c,0x65,0x8f,0x13,0x8b,0xfd,
	0xbe,0xcb,0x54,0xb2,0x21,0xf7,0xb8,0x88,
	0xa0,0x9e,0x8f,0xb0,0x8f,0x25,0x9f,0xd4,
	0x8f,0x27,0x91,0xde,0x1c,0x90,0xf0,0x40,
	0xef,0x8f,0x01,0x9f,0x13,0x9f,0x88,0x9f,
	0x37,0x9f,0x0e,0xa2,0x1e,0x03,0x54,0x60,
	0x56,0x9f,0xcb,0x9f,0x7a,0x9f,0x8c,0x9f,
	0x9e,0x9f,0xff,0xfd,0x4e,0x91,0xc1,0xfc,
	0x3f,0x40,0xb2,0x21,0x92,0x8f,0x33,0xaf,
	0xe2,0x92,0xcf,0xff,0x31,0xee,0xdb,0xcf,
	0xfc,0x9f,0x0e,0xa9,0xff,0x0f,0x28,0x83,
	0xbe,0x9f,0x9c,0x97,0xaf,0xe2,0x92,0xb7,
	0xff,0xec,0x6b,0xef,0x60,0xa4,0xe1,0x80,
	0xfe,0x00,0x6b,0xaf,0xd9,0x31,0x81,0xaf,
	0xb7,0xaf,0xa5,0xaf,0x1a,0xbf,0xfe,0x1f,
	0xff,0x9e,0x7f,0xf9,0xe7,0xcf,0xaf,0x68,
	0x50,0xb8,0x9a,0x4d,0xf0,0x61,0x7e,0x00,
	0x00,0x2e,0xf0,0x08,0xba,0xea,0x97,0xff,
	0x9e,0x60,0xa4,0xbf,0x7f,0xfb,0xf7,0x77,
	0x8c,0x82,0x62,0xf0,0xc8,0x1c,0xaa,0x55,
	0xbf,0x67,0xbd,0x8f,0x78,0xbf,0x5e,0xa6,
	0x7f,0xbf,0xb3,0xf7,0xfb,0x13,0x8e,0xac,
	0x22,0xe0,0x01,0x9b,0x67,0xf3,0x88,0xf2,
	0xaf,0x53,0x93,0xde,0x96,0xbf,0xdc,0xbf,
	0xee,0xbf,0x00,0xcc,0xfe,0x11,0x0f,0x11,
	0xcf,0x23,0xcf,0x09,0xb9,0xe6,0x16,0xbf,
	0x54,0xcf,0xda,0x1c,0x00,0xb0,0x79,0x81,
	0xcf,0x93,0xcf,0xa5,0xcf,0xb7,0xcf,0x11,
	0x1e,0xda,0xcf,0xec,0xcf,0x94,0x42,0xaf,
	0xe5,0x3e,0x00,0x92,0xb2,0xfc,0x71,0x71,
	0xc8,0xcd,0xef,0x07,0x80,0x00,0x7f,0x40,
	0xdf,0x52,0xdf,0xe0,0x9f,0xd6,0xdb,0x11,
	0x40,0x08,0x2f,0xb1,0x73,0x42,0xc8,0xcd,
	0xff,0xa1,0xdf,0xb3,0xdf,0xc5,0xdf,0x3a,
	0xee,0x00,0x97,0x20,0xcb,0xa1,0x5f,0xf2,
	0xf4,0xde,0xd1,0x59,0x11,0xef,0x23,0xef,
	0x98,0xef,0xc0,0x47,0xe5,0xe2,0xd6,0x58,
	0xef,0x6a,0xef,0x7c,0xef,0x62,0xd8,0xf1,
	0x83,0x03,0x1c,0x6d,0x9e,0xef,0x32,0x21,
	0xac,0xf4,0xba,0xef,0xcc,0xef,0xde,0xef,
	0x1e,0x08,0xba,0xee,0xbe,0xeb,0xad,0x02,
	0xff,0x32,0x20,0x50,0x78,0x10,0x49,0x0e,
	0x32,0xff,0x44,0xff,0x56,0xfb,0xab,0x66,
	0xff,0x77,0xff,0xb1,0x09,0xf0,0x5d,0x70,
	0x98,0xff,0xaa,0xff,0x90,0xe4,0xf7,0xff,
	0xef,0xbe,0x03,0xeb,0xeb,0xca,0xff,0x93,
	0xe0,0x9d,0x64,0xaf,0x72,0xea,0xff,0xfc,
	0xff,0x60,0x0e,0x0f,0x0c,0xb6,0x29,0x00,
	0x4b,0x72,0xd6,0x9c,0x7f,0xf0,0x9d,0x62,
	0x41,0xfc,0xae,0x73,0x86,0xfd,0x0a,0x58,
	0x69,0x0f,0x87,0xed,0x8f,0x28,0x0f,0x16,
	0x9e,0x04,0xcf,0x3c,0xc9,0x02,0xcf,0xad,
	0x0f,0xf5,0x00,0x9a,0x68,0xe0,0xcd,0x09,
	0xb9,0xba,0x72,0x73,0x3c,0xc2,0xc5,0xff,
	0xfe,0x07,0xff,0xff,0xf8,0x3f,0x7f,0xdf,
	0xbc,0xfe,0x00,0x01,0x80,0x59,0x30,0x11,
	0x1f,0x74,0x31,0x27,0x1f,0xf5,0x01,0x6e,
	0xd5,0xb8,0x92,0x87,0xf8,0x4b,0x1a,0x64,
	0xfc,0x67,0x10,0xfb,0x7f,0x7f,0xbf,0xdc,
	0x26,0x6f,0x11,0xef,0xf7,0x75,0x1f,0xf5,
	0x00,0x03,0x8b,0x1f,0xb3,0x54,0x7a,0xdc,
	0x07,0xe3,0x8f,0xe5,0x87,0xff,0xf1,0xbf,
	0xff,0xef,0xbf,0xff,0xfd,0x7e,0xff,0xbf,
	0xc0,0x6f,0x10,0xc0,0x8f,0x0f,0xf7,0xfd,
	0xf1,0xdb,0x1f,0x35,0x69,0xcd,0x09,0x9f,
	0xc0,0xcd,0x00,0x12,0x21,0xb8,0x92,0xcd,
	0x02,0x93,0xef,0x29,0x2f,0x0f,0xe7,0xe3,
	0xfd,0xee,0x3f,0x2f,0x15,0x39,0xcd,0x09,
	0x3f,0xed,0xff,0x13,0xff,0xdd,0x2e,0xc1,
	0x11,0x40,0x1f,0x7e,0x61,0x7a,0x2f,0xe5,
	0x24,0xbb,0xf8,0x00,0x84,0x80,0xff,0xbf,
	0xdf,0x6f,0x10,0xcf,0x81,0xef,0xa0,0x2f,
	0xa8,0xb1,0x3e,0xdf,0x2d,0xf3,0x65,0xa0,
	0xd1,0x24,0xfe,0xd9,0xef,0xda,0x2f,0xec,
	0x2e,0xdf,0xbf,0xff,0x21,0xf7,0xef,0x01,
	0xfd,0x65,0xa2,0xa7,0x2c,0xc2,0x0f,0x2d,
	0xf3,0x19,0x30,0x35,0x3f,0x1d,0xf0,0xb9,
	0xcf,0x42,0xcf,0x06,0x40,0xff,0xcf,0x3f,
	0xff,0x21,0xf3,0x03,0xcf,0xfd,0x3e,0x33,
	0x88,0xfa,0x67,0x10,0x80,0x3f,0x41,0x31,
	0x06,0x30,0x9a,0x6d,0x22,0xf7,0x9f,0x3b,
	0xfb,0xb7,0xaf,0x3f,0x63,0xa1,0xf0,0x4d,
	0xff,0xff,0x21,0xfc,0x3f,0x69,0x3f,0xcf,
	0x50,0x83,0xe3,0x3f,0x48,0xf5,0x35,0xd1,
	0x22,0x02,0x4a,0x83,0x10,0x4f,0x5f,0x70,
	0x3f,0x64,0xa2,0x08,0xff,0x21,0xe7,0x80,
	0x06,0x3f,0x8f,0x45,0x4f,0x89,0xf4,0x5e,
	0x48,0xce,0xa3,0x0e,0x0f,0xb3,0xfb,0xf7,
	0x5f,0x78,0x4f,0x64,0xa3,0x87,0xe2,0x95,
	0x4f,0x27,0xff,0x0f,0xfe,0x52,0x2f,0xbc,
	0x4b,0xfb,0x64,0xa0,0x9d,0x63,0x1e,0x44,
	0x30,0xd7,0xff,0xe0,0xb7,0xdb,0x4d,0x45,
	0x71,0xef,0x48,0xe6,0x3e,0x2e,0xfc,0x0f,
	0xb5,0x2f,0x89,0xf4,0xf1,0xe0,0x7f,0xff,
	0xe3,0x80,0xff,0xfe,0x03,0xfb,0xfc,0x0f,
	0x8d,0x6f,0x32,0x58,0xfb,0x8f,0x3f,0x5f,
	0x51,0x5a,0xda,0x1e,0xf8,0xf9,0x4f,0x19,
	0x3f,0x89,0xf5,0xc6,0x3f,0xff,0x08,0x7f,
	0xbf,0xfc,0x01,0x83,0xf8,0xc7,0x9f,0x32,
	0x56,0xe7,0x87,0xff,0xfb,0xbe,0xd6,0x20,
	0xa6,0x5f,0xb8,0x5f,0x8a,0xf6,0xe1,0xd9,
	0xcf,0x71,0x5f,0x60,0xa5,0x9f,0x1f,0x81,
	0x60,0xfc,0xf9,0x87,0xff,0xf1,0xe7,0x31,
	0x57,0x03,0x6f,0x15,0x6f,0xcf,0x3d,0xc3,
	0xe9,0xcf,0x0d,0x5f,0x4b,0x66,0x9f,0xa2,
	0x00,0xfc,0xfd,0xff,0x13,0xf3,0xf3,0xee,
	0x44,0xa8,0x33,0x86,0x6b,0x6f,0x41,0x36,
	0xb8,0x90,0x02,0xd9,0x1f,0x87,0x44,0x4f,
	0xf6,0xa3,0xb4,0x70,0xb7,0x6f,0x15,0x4f,
	0xdb,0x6f,0x32,0xed,0x6e,0xfe,0x1b,0xa0,
	0x02,0x7f,0xff,0x81,0x16,0x7e,0x2c,0x72,
	0x38,0x2c,0x7f,0x3e,0x7f,0x50,0x7f,0xfc,
	0x3f,0xcf,0x25,0x1f,0x77,0x76,0x20,0x54,
	0x67,0x8a,0x7f,0x9c,0x7f,0xae,0x7f,0x8c,
	0xf3,0xf0,0xb7,0x90,0x7e,0x3f,0xfa,0xe5,
	0x82,0xff,0xee,0x51,0x1c,0xff,0xfe,0x31,
	0xff,0x7b,0xf8,0xc7,0xed,0x77,0xcf,0xff,
	0xf2,0xba,0x3a,0x60,0x52,0xfe,0x7f,0x7f,
	0xad,0x10,0xb6,0x90,0x87,0x18,0x8f,0xe1,
	0x88,0xe0,0x2c,0x3a,0x6f,0x40,0x84,0xe0,
	0x7f,0x78,0x71,0x07,0x50,0x21,0xee,0x76,
	0xf2,0x13,0xb0,0xb2,0xb0,0xe6,0xee,0xa9,
	0xbf,0xfe,0x79,0xff,0x4f,0xe7,0x9f,0xce,
	0x79,0x1c,0xf1,0x08,0x3b,0xc3,0x88,0xe0,
	0x82,0x2e,0x8f,0xfe,0x88,0x40,0x3e,0x33,
	0x90,0x03,0x92,0x80,0xb7,0x87,0xee,0xf9,
	0xb2,0xcf,0x6f,0xd5,0x82,0xfd,0xff,0xef,
	0xdf,0xce,0x3d,0xfd,0xe0,0x8d,0xfe,0x0f,
	0x0f,0xff,0xe4,0xa3,0xfa,0x8f,0x58,0x0c,
	0x9c,0x5f,0x82,0xa8,0x32,0xec,0xaa,0x27,
	0x9e,0x80,0x40,0x11,0x7f,0x01,0xfe,0xff,
	0xdf,0xef,0xcd,0xfe,0xe0,0x8d,0x07,0xfc,
	0xe6,0x1f,0x57,0x90,0xca,0x7f,0xfa,0x71,
	0x70,0x9f,0x66,0xd4,0x89,0xef,0x8a,0x9f,
	0x9c,0x92,0x00,0xa2,0x92,0xde,0xf8,0x40,
	0x13,0x01,0x03,0xf0,0x3f,0x86,0x40,0x3e,
	0x18,0xee,0x10,0xcc,0x9f,0x7a,0x9c,0xed,
	0x9f,0x92,0x57,0xa3,0xfc,0x06,0xaf,0x18,
	0xa3,0x7f,0x1f,0xaf,0x7b,0x60,0xf0,0x20,
	0x68,0xb0,0xed,0x63,0x8a,0x10,0x79,0x9b,
	0x5f,0xf0,0x9a,0x53,0xaf,0xe5,0xd1,0xf8,
	0x31,0x40,0xa4,0x92,0xc3,0x8a,0xfe,0x7f,
	0xfd,0xe4,0x3f,0x00,0xbb,0x9b,0x33,0x94,
	0x98,0xa7,0x79,0x70,0x2f,0xf3,0x13,0x42,
	0xb0,0xa4,0xc3,0x8e,0x18,0x9c,0xd2,0x3d,
	0x95,0xd5,0xac,0xfc,0xcf,0x56,0x9c,0x33,
	0x95,0xee,0xd0,0x00,0xcd,0x02,0x40,0x14,
	0x0c,0xb8,0xfb,0xe0,0x5e,0x8f,0x19,0xf2,
	0xd9,0x85,0x13,0x49,0xff,0xdc,0x1e,0x7f,
	0xfe,0x1f,0x87,0xff,0xcf,0x06,0x51,0xe1,
	0xfc,0xf7,0x05,0x25,0x5b,0xbf,0x6d,0xb3,
	0xd2,0x02,0xf4,0x7f,0x2a,0xdf,0xd7,0xf7,
	0x75,0x85,0xbf,0xb7,0xb8,0xdd,0xee,0x85,
	0x29,0xd1,0x03,0xf7,0x77,0xb8,0xbf,0x2f,
	0xf1,0x06,0xb3,0xcf,0x05,0xdc,0xbf,0xdf,
	0xd7,0x14,0xed,0x63,0x71,0x20,0x7f,0x1b,
	0xc8,0xde,0x26,0x82,0x13,0xcf,0xc1,0xb4,
	0x82,0xe1,0x82,0x3f,0xa2,0xa3,0x38,0xcf,
	0x4a,0xcf,0x5c,0xcf,0xad,0xe1,0x7e,0x00,
	0xa4,0xc0,0x78,0x80,0x79,0xc3,0xe1,0x88,
	0x8a,0xc9,0xa7,0xeb,0x18,0x22,0x6d,0xdf,
	0x64,0x19,0xf2,0xce,0x43,0xcf,0x8a,0x40,
	0xe1,0x88,0xdf,0xbe,0x5f,0x74,0xe0,0x7a,
	0xc2,0x7d,0x08,0xc2,0xb3,0x90,0x02,0xf9,
	0xcf,0xbf,0xff,0xec,0xb1,0xbb,0x11,0xdf,
	0x92,0xb1,0xdc,0x04,0xfd,0xff,0xca,0xc9,
	0xde,0x85,0x7f,0x3e,0x30,0x0f,0xdc,0xcf,
	0x52,0xdf,0x86,0xe5,0xa4,0xc0,0xdf,0x98,
	0x70,0xdf,0x8f,0xb4,0x3f,0x44,0xf9,0xff,
	0x5a,0x90,0x05,0xc6,0xde,0x43,0x7f,0xf8,
	0xfd,0x62,0x7a,0xcf,0xb8,0xdf,0xca,0xd8,
	0xea,0x13,0x4f,0x50,0x46,0x02,0x3f,0x44,
	0x4f,0xe4,0x3d,0xe3,0x1d,0x02,0xe0,0x3f,
	0x36,0x60,0xc2,0x91,0xf2,0xc7,0x0f,0xef,
	0xc9,0x70,0xb1,0xb0,0x39,0x60,0xe0,0xff,
	0x8b,0xff,0xc1,0xca,0xd6,0xef,0x38,0xef,
	0x44,0x04,0x9e,0xe2,0xcf,0x5c,0x1c,0xf0,
	0xa4,0xc8,0xde,0x3e,0x7f,0x7d,0x30,0xf0,
	0x08,0xe4,0xee,0xb7,0xbe,0xef,0xfe,0x21,
	0x4e,0x81,0xf3,0x8f,0xff,0x49,0xc4,0xf0,
	0x50,0xca,0xd6,0xf7,0x9c,0xef,0x05,0xf2,
	0x83,0x66,0xd3,0x88,0xeb,0x90,0xc9,0x71,
	0x85,0xf8,0xf9,0x76,0x80,0xf6,0xd2,0x51,
	0xbf,0xff,0xfd,0xef,0x58,0x60,0xfb,0xf3,
	0xff,0xe7,0xcf,0xff,0x9f,0x9f,0x3f,0xff,
	0x3c,0x7f,0x27,0x92,0xbc,0x82,0xe6,0x60,
	0xd6,0xdf,0x2b,0xb3,0xdd,0x03,0xc3,0x8b,
	0x2e,0xf0,0xc3,0xff,0x9d,0x61,0x6a,0x37,
	0xff,0xe0,0x40,0x11,0xf9,0xbe,0x61,0xe7,
	0xef,0x1a,0x71,0x31,0x7e,0x5a,0xff,0xda,
	0xdf,0xf6,0x20,0x00,0x4f,0x9c,0xba,0x2c,
	0xf2,0xf1,0xe1,0x0a,0x50,0x99,0xff,0xab,
	0xf3,0x01,0xfc,0xff,0xf7,0x37,0xf3,0xff,
	0xef,0xb8,0xf2,0x7f,0x7f,0x90,0x02,0xe8,
	0x92,0x38,0x0d,0xdf,0x33,0x03,0x4e,0xf0,
	0xff,0xff,0x4f,0x1e,0x15,0x27,0xf7,0x23,
	0xf8,0x7f,0x77,0xc4,0x64,0x8d,0xdf,0x00,
	0xf9,0xbd,0x62,0x1b,0x03,0x81,0x7e,0x22,
	0x06,0x8e,0x0f,0x61,0xa6,0x46,0x02,0xed,
	0xaa,0x2c,0xf2,0xfc,0x19,0x3f,0x7c,0xf3,
	0x65,0x0f,0xff,0xdf,0x58,0x60,0xb4,0xf1,
	0x54,0xf3,0x09,0x77,0x87,0x0f,0xfc,0x0e,
	0x7f,0x47,0x01,0xed,0x6a,0x2c,0xf2,0x97,
	0xf3,0xfc,0xc7,0x0f,0x64,0xd1,0xfe,0x71,
	0xc7,0xf8,0xc7,0xdf,0x7f,0xf3,0x9c,0x7f,
	0xc6,0x38,0x3f,0x18,0xaa,0xd3,0x00,0xf0,
	0x0f,0x70,0x6a,0x47,0x01,0x12,0x93,0x25,
	0xf9,0xad,0x14,0x2c,0x1f,0x7a,0x60,0xff,
	0xfe,0x03,0xbb,0xfc,0x0f,0xdf,0xf0,0x3b,
	0xdf,0xbf,0xe0,0x7b,0xff,0x81,0x4e,0x16,
	0xef,0xff,0x07,0xe3,0xbb,0xbb,0x02,0xff,
	0x0e,0x92,0x47,0x01,0xfe,0x14,0x7e,0x19,
	0xe8,0x96,0xc4,0x91,0x1f,0x7b,0x61,0xbb,
	0x96,0xf0,0xfc,0xfb,0xbf,0x88,0x79,0x00,
	0x17,0x01,0x95,0xe5,0xed,0xbe,0x1f,0x3f,
	0x04,0xed,0x60,0x4e,0xc0,0x54,0x1c,0x86,
	0x11,0xd5,0x51,0xf2,0x1f,0xee,0x34,0x2e,
	0x50,0xdf,0xfc,0xe7,0xff,0xbf,0xf9,0x8b,
	0x40,0x16,0x28,0xee,0x83,0xb8,0xc8,0x7f,
	0xbf,0x72,0x32,0xed,0x60,0x49,0x18,0x4d,
	0x9f,0xd0,0xf8,0x7c,0xb8,0xf6,0x80,0x57,
	0x2f,0x05,0x25,0xff,0x5f,0xfc,0x86,0x11,
	0x7f,0x78,0x79,0x2a,0x22,0x2f,0xf1,0x24,
	0x0b,0xf8,0xff,0x47,0xa3,0x2f,0x87,0xff,
	0xfc,0x19,0x67,0xd2,0xbd,0x2f,0xb4,0xe1,
	0x8a,0x10,0x5f,0x64,0x73,0x21,0x6e,0xd0,
	0xf7,0xed,0x62,0x80,0x23,0xd7,0xbd,0x54,
	0x1f,0xc6,0x4c,0x43,0xf7,0x7f,0xf6,0xd5,
	0xe3,0xf0,0x15,0xa5,0xff,0xff,0xa1,0x03,
	0x84,0xa4,0x7c,0x30,0xc2,0x2e,0xec,0x20,
	0x9f,0x0f,0x21,0xfb,0x07,0xbf,0xff,0xc7,
	0x7b,0x28,0x4e,0x3f,0xd9,0xf6,0xdb,0xc3,
	0x6f,0x3e,0x00,0xad,0xf2,0x85,0x3f,0x97,
	0x3c,0x7a,0x29,0xb2,0x3f,0xc4,0x3f,0x6a,
	0x43,0x84,0x13,0xe3,0xfe,0x0b,0x60,0x0f,
	0x02,0x26,0x66,0x70,0xdf,0xfc,0xfc,0x38,
	0xbf,0x00,0xc8,0x63,0xe6,0x94,0xed,0xef,
	0xbe,0x1e,0x4f,0xc6,0x3d,0x04,0xf9,0xf0,
	0x11,0x37,0x39,0xae,0x62,0x4d,0x4f,0x5f,
	0x03,0xbf,0x92,0x0c,0x92,0x0c,0x23,0x05,
	0xbb,0x10,0xee,0x0e,0x82,0x4f,0xe6,0x43,
	0x76,0xc4,0x14,0xf2,0x00,0x48,0x28,0xc1,
	0x00,0xae,0x41,0xed,0x69,0xae,0x63,0x77,
	0x14,0xcb,0x45,0xf7,0xe5,0x10,0x3e,0x5f,
	0xd6,0xfa,0xfa,0x4c,0xc9,0xe0,0xf9,0x9d,
	0x45,0x15,0x5f,0xa8,0x63,0x18,0xc9,0x47,
	0x9f,0xcf,0xac,0x5f,0xff,0xfb,0x31,0x46,
	0x8e,0xe0,0xfd,0xd4,0x00,0xec,0x17,0x7a,
	0x5f,0x72,0x37,0x6b,0xb5,0x9e,0x56,0xb8,
	0x22,0x0f,0x6f,0xbf,0x91,0x00,0xce,0x36,
	0x5f,0x83,0xd1,0x52,0x26,0x15,0x89,0x69,
	0xdb,0x1a,0xcb,0x45,0x27,0x74,0x3f,0xef,
	0xee,0xef,0xf1,0xee,0xeb,0x26,0x9f,0x27,
	0xea,0x80,0xf7,0x61,0x0b,0x63,0xd1,0x51,
	0x92,0x64,0x40,0x6f,0x52,0x6f,0x64,0x66,
	0xee,0x07,0xef,0x1b,0xad,0x71,0x6f,0x83,
	0x6c,0xcc,0xe0,0xcd,0x55,0x2e,0x64,0x18,
	0xa4,0x6f,0xb6,0x6f,0xc8,0x67,0xee,0xfb,
	0xd4,0x6f,0x82,0x6d,0xab,0x80,0xc0,0xcd,
	0x55,0x52,0x24,0x68,0xa1,0x0c,0x7f,0x1e,
	0x7f,0x68,0x62,0xfd,0xef,0xf3,0x3b,0xb1,
	0x39,0x7f,0x83,0x6c,0xc1,0xff,0xde,0x37,
	0xc0,0xa0,0x50,0xd1,0x51,0x9e,0x45,0x6d,
	0x7f,0x7f,0x7f,0x9d,0x52,0xe1,0xee,0xcf,
	0xef,0xfb,0xee,0xdb,0x38,0x7f,0x82,0x6d,
	0x87,0xff,0x03,0xdd,0xd6,0x62,0xe3,0x30,
	0xf0,0x53,0x24,0xca,0x54,0xd9,0x7f,0x87,
	0x7c,0x7f,0xee,0xee,0x1f,0xf7,0xef,0x28,
	0x73,0x01,0x8f,0x1e,0x83,0x6c,0xc0,0xff,
	0xdd,0xd5,0x6a,0x54,0xf6,0xd5,0xb1,0x4f,
	0x84,0x47,0x8f,0x59,0x83,0xff,0xc1,0x81,
	0xc3,0x03,0xcd,0x8f,0x88,0x67,0xf0,0x07,
	0x3f,0xdd,0xd3,0x4e,0x93,0xf6,0x64,0x97,
	0x8f,0xa9,0x8f,0x57,0x85,0x30,0x13,0x40,
	0xef,0x90,0xc9,0x8f,0x83,0x6c,0xfc,0x1f,
	0x88,0x82,0xf1,0x81,0x70,0xa0,0x55,0xfd,
	0x8f,0x0f,0x9f,0xf5,0x73,0xef,0xff,0xf1,
	0x2a,0x9f,0x00,0x3c,0x9f,0x4e,0x90,0x25,
	0x81,0xf1,0x81,0x73,0x98,0x64,0x9f,0x76,
	0x9f,0xa0,0x5f,0x1c,0x9a,0x9f,0xf2,0x44,
	0x7f,0xdd,0xd7,0xde,0xa3,0xde,0x56,0xc5,
	0x9f,0x10,0xd7,0x9f,0xe9,0x9f,0x5e,0xaf,
	0xb5,0x78,0x1d,0x19,0xa4,0x3a,0xa9,0x2c,
	0xaf,0xc0,0x3e,0xaf,0x68,0x60,0x4e,0xa6,
	0x77,0x20,0x1b,0xbf,0x19,0x88,0xde,0x37,
	0xf8,0x7e,0xaf,0x90,0xaf,0xa2,0xaf,0x7e,
	0xfc,0x6f,0x87,0xfe,0xff,0xea,0xee,0xee,
	0xff,0x8f,0x1b,0xbf,0xce,0x01,0xfe,0x29,
	0x91,0xc6,0xaf,0xb8,0x75,0x3c,0x45,0xe8,
	0xaf,0xfa,0xaf,0x0c,0xba,0xf7,0xfb,0xb7,
	0xbf,0x1c,0xb2,0xb7,0xbb,0x3f,0xb6,0x81,
	0x1e,0x26,0xbf,0x0c,0xa9,0x3c,0x45,0x20,
	0xaf,0x5e,0xbf,0x70,0xbc,0xdf,0x35,0xfd,
	0x1d,0xb1,0xbb,0x86,0xb0,0xee,0xee,0xe3,
	0xc8,0xa2,0x9f,0xb0,0x3c,0x45,0xbc,0x9f,
	0xc2,0xbf,0x0c,0xba,0xff,0x7b,0xe3,0xb4,
	0xba,0xc1,0xbf,0xec,0xbf,0xfe,0xbf,0x54,
	0x9f,0x22,0xcf,0x08,0xbe,0x1e,0xfb,0x05,
	0xef,0x48,0xc5,0x8e,0x51,0xcf,0xeb,0x69,
	0x5d,0xd4,0xf2,0x80,0x5d,0xd5,0xf2,0x39,
	0xfa,0x80,0xf2,0x5a,0x0c,0xba,0xed,0xfb,
	0xf7,0xfd,0x77,0xe5,0xee,0x1e,0x4c,0xc1,
	0xbe,0x1e,0xe1,0xb7,0xcf,0xe0,0x25,0x67,
	0x3b,0x47,0x91,0x8f,0xef,0xcf,0x0d,0xb9,
	0xeb,0xbd,0xb7,0x1e,0x0a,0x72,0xbb,0xb9,
	0xbf,0xb7,0x6d,0x44,0x20,0xdf,0x36,0x4c,
	0xd0,0x2d,0x86,0x80,0xdf,0x3b,0x09,0x68,
	0xd9,0xfe,0xe7,0xe0,0xff,0xb7,0x00,0x7a,
	0xd0,0xd8,0xd0,0xb8,0xdf,0x92,0xdf,0xc8,
	0x77,0xe4,0xdf,0xc0,0xdf,0x16,0xb0,0x07,
	0x1c,0x7e,0xcf,0xd8,0xd2,0x21,0xb0,0x3b,
	0xe1,0x1c,0xef,0xe2,0x86,0x00,0x3b,0x47,
	0x65,0x76,0x48,0xef,0x24,0xef,0x4e,0xa1,
	0x77,0x20,0x50,0xa7,0xc3,0xaf,0x00,0x51,
	0x7d,0x59,0x04,0x70,0xef,0x82,0xef,0x48,
	0xaf,0x09,0xff,0x84,0x6a,0xe3,0xf0,0x00,
	0x1c,0x17,0x9e,0x65,0x10,0xff,0xec,0xef,
	0xfe,0xef,0x73,0xff,0x22,0xff,0x38,0x67,
	0x20,0x74,0xff,0x50,0xff,0x62,0xff,0xd7,
	0xff,0xbe,0xef,0xf9,0x01,0x55,0xa1,0xff,
	0x00,0xb3,0xff,0xc5,0xff,0x3a,0x0f,0x59,
	0xef,0x6f,0x58,0x3c,0x0f,0x18,0x0f,0x2a,
	0x0f,0x00,0x9f,0x0f,0xce,0x35,0x46,0x2a,
	0x0f,0x54,0xa0,0x0f,0x7c,0x0f,0x8e,0x0f,
	0x03,0x1f,0x81,0xcf,0x9d,0x46,0xa0,0x4f,
	0x04,0x1f,0xe0,0x0f,0xf2,0x0f,0x67,0x1f,
	0xcf,0x00,0x85,0x80,0x0a,0x3d,0x46,0x4f,
	0x9f,0x1f,0x4e,0x1f,0xc3,0x1f,0xcc,0x15,
	0x80,0x34,0x00,0xf4,0x58,0xe0,0x38,0xfa,
	0x1f,0xe7,0x19,0xb5,0x1f,0x2a,0x2f,0xd9,
	0x1f,0x77,0x3d,0x60,0x5e,0x2f,0x0d,0x2f,
	0x1f,0x2f,0x94,0x2f,0x7b,0x1f,0xff,0xfe,
	0x1b,0x3f,0x60,0xcc,0x2f,0x7b,0x2f,0xf0,
	0x2f,0xfa,0x26,0x18,0x1f,0xf8,0x7c,0x0b,
	0x62,0x00,0xc1,0x2f,0x36,0x3f,0xe5,0x2f,
	0x5a,0x3f,0x89,0x57,0xbb,0x09,0xd7,0x55,
	0x7f,0xdf,0x60,0x9c,0x3f,0x4b,0x3f,0xc0,
	0x3f,0xd5,0x55,0xc2,0x33,0xef,0xbe,0xd3,
	0x59,0x30,0x8b,0x3f,0x00,0x4f,0xaf,0x3f,
	0x24,0x4f,0xff,0x07,0xd5,0x3e,0x2d,0x84,
	0x8f,0xfc,0xfb,0x83,0xfe,0x38,0x4a,0x61,
	0x4f,0x10,0x44,0xcf,0x87,0xff,0xee,0xc7,
	0x66,0x4f,0x2d,0x4f,0xdb,0x38,0x9a,0xf5,
	0xfb,0x11,0xb7,0x54,0x4f,0xc9,0x4f,0x14,
	0x40,0xb7,0x28,0x92,0xe4,0x4f,0xee,0x46,
	0x00,0x42,0xb5,0xdc,0x36,0xc7,0x03,0xdb,
	0x51,0x19,0xa2,0x1f,0x5f,0xce,0x4f,0xe0,
	0x4f,0x80,0x52,0x5b,0xa6,0xb5,0xdc,0x36,
	0xd1,0xe6,0x1a,0x5f,0x8f,0x5f,0x12,0x42,
	0xf7,0x83,0xff,0xed,0x46,0x5f,0x18,0x6a,
	0xdd,0xc5,0xdd,0x35,0x36,0x85,0xfc,0x47,
	0xfb,0xe7,0xf8,0x2b,0xf4,0xeb,0x5f,0x0a,
	0x4a,0xc7,0x89,0x91,0x30,0x0f,0x6f,0x5a,
	0x58,0xc9,0x5d,0xd4,0x35,0xfc,0xe3,0xe3,
	0x5f,0x58,0x6f,0x58,0x3f,0x5f,0x7c,0x6f,
	0x85,0x80,0x78,0xdd,0x7e,0x66,0x8e,0x8e,
	0x80,0xa0,0x2d,0x86,0xee,0x3f,0xbb,0x6f,
	0x6a,0x6f,0xdf,0x6f,0xff,0xfd,0xf0,0x77,
	0x81,0x5b,0xd8,0x39,0xf4,0x8f,0x15,0x7f,
	0xc4,0x6f,0xd6,0x6f,0x46,0x79,0x0f,0x67,
	0xff,0x77,0x57,0xac,0x29,0xdc,0xc9,0xc0,
	0x00,0x05,0x75,0xe4,0x7d,0x7f,0x70,0x4a,
	0xe1,0x7e,0x4f,0xaa,0x79,0x81,0xff,0x77,
	0x81,0x4f,0x5c,0x7a,0x79,0xc8,0x74,0x7f,
	0xe9,0x7f,0x14,0x4f,0x0d,0x8f,0xe0,0x01,
	0x7f,0x5a,0x7b,0xb6,0x86,0x49,0xd1,0x8e,
	0xca,0x49,0x8f,0xf8,0x7f,0x6d,0x8f,0x80,
	0xce,0xc3,0xf6,0x68,0x49,0xbd,0x3d,0x8f,
	0x4f,0x8f,0xb2,0x8f,0x73,0x8f,0x3f,0xc3,
	0x77,0x5f,0x88,0x8f,0x9a,0x8f,0x0f,0x9f,
	0x72,0x48,0xf1,0xef,0x04,0xda,0x7f,0x15,
	0x89,0xfc,0xea,0x8f,0xfc,0x8f,0x71,0x9f,
	0x2c,0x7b,0x39,0x7f,0x02,0xe8,0x6b,0x78,
	0xab,0xe8,0x5a,0x9f,0xcf,0x9f,0x7e,0x9f,
	0x90,0x9f,0x4a,0x7d,0xc4,0xaa,0x2b,0x4c,
	0xb9,0xef,0xcd,0x9f,0xdf,0x9f,0x35,0x71,
	0xef,0xef,0xc0,0xab,0xef,0xe9,0x6a,0x16,
	0xaf,0x28,0xaf,0x9d,0xaf,0x70,0x4a,0xef,
	0xef,0x21,0xbf,0xa6,0xaf,0x16,0x88,0x79,
	0xaf,0x07,0x76,0x83,0x95,0xaf,0xa7,0xaf,
	0x00,0x55,0xa3,0xc4,0x8f,0x79,0x8a,0xde,
	0xaf,0x8c,0xaf,0x65,0xbf,0xe8,0x9f,0x89,
	0xbf,0x00,0x38,0xbf,0x4a,0xbf,0x5c,0xbf,
	0xd1,0xbf,0x80,0xbf,0xf5,0xbf,0x64,0x5a,
	0xbd,0x9f,0x48,0x26,0xcf,0xd5,0xbf,0x2b,
	0x90,0x83,0x2f,0x9f,0x5a,0xc8,0xf1,0xdd,
	0xaf,0x00,0x1b,0xcf,0x90,0xcf,0xbb,0x8f,
	0xb4,0xcf,0x67,0x3f,0x75,0xcf,0x87,0xc3,
	0xac,0xcf,0x00,0x9f,0xcf,0x14,0xdf,0xc3,
	0xcf,0xd5,0xcf,0xe7,0xcf,0x5c,0xdf,0x0b,
	0xdf,0x80,0xdf,0x44,0x07,0x3f,0x41,0xdb,
	0xfc,0x78,0x22,0x74,0xdf,0x67,0xdd,0xdf,
	0x38,0x70,0x70,0x4f,0xcf,0x9d,0x2f,0x9f,
	0xdf,0xb1,0xd3,0xe3,0x77,0x16,0xea,0xdf,
	0x98,0xcc,0xdf,0xea,0xbf,0xfd,0xb9,0x00,
	0x03,0xfe,0xdf,0x08,0x78,0xdd,0x03,0xf7,
	0x66,0x4d,0xef,0x30,0xef,0x42,0xef,0x54,
	0xef,0x66,0xef,0x78,0xe6,0x09,0x76,0xb1,
	0xef,0x68,0xdc,0xef,0xa8,0x50,0x5b,0xaf,
	0xf1,0xdf,0xcb,0xef,0x08,0xdd,0xef,0x52,
	0xff,0x01,0xf5,0xe1,0xbe,0xaf,0x8c,0xdf,
	0x2e,0xff,0x40,0xf7,0x04,0xdf,0xdf,0xf8,
	0xee,0xee,0x22,0xbf,0xe3,0xff,0x92,0xff,
	0x40,0xff,0x19,0x0f,0xe0,0xa0,0x56,0xa5,
	0xef,0x46,0x0f,0xf5,0xff,0xbb,0xb2,0xf0,
	0x00,0x7f,0x07,0xdd,0xf7,0xfe,0x50,0x0f,
	0x24,0x0f,0x36,0x0f,0xab,0x0f,0x1b,0x83,
	0x7c,0x6f,0x20,0x43,0xda,0x80,0x00,0x0f,
	0xdd,0xc7,0x75,0x0c,0x39,0xdf,0xd3,0xfc,
	0xd3,0xf0,0x87,0xff,0xe1,0x4e,0xcf,0x0f,
	0x1f,0xfc,0xbe,0x0f,0xbc,0xb0,0xfe,0x07,
	0x9f,0x03,0xe3,0xf7,0x09,0xfe,0x14,0xab,
	0xd2,0xf2,0x8f,0x6a,0xdf,0x63,0x1f,0x75,
	0x1f,0x79,0x10,0xed,0xe7,0x08,0xed,0x1f,
	0x9f,0x0c,0x3b,0xff,0xff,0x7b,0x7f,0xfd,
	0xf7,0x0e,0x3f,0xbf,0x65,0x77,0x52,0x1f,
	0x78,0xc7,0x1f,0xd9,0x1f,0x88,0x1f,0xff,
	0xfc,0x7f,0x9f,0x6c,0xcb,0x1e,0xac,0x12,
	0x75,0xdf,0xbf,0x59,0x14,0xa8,0xc0,0x1f,
	0x35,0x2f,0xbc,0xe4,0x1f,0xb6,0xb6,0xfd,
	0xff,0x9f,0xfd,0x03,0x2e,0xeb,0xcf,0x75,
	0xff,0xbf,0x5d,0x24,0x28,0x78,0x42,0xe3,
	0xc6,0x24,0x9b,0x0f,0xa0,0x2f,0xff,0x6f,
	0xf0,0x8b,0x10,0x1e,0x43,0xdf,0xa2,0x2a,
	0x7f,0x03,0xfd,0xeb,0x74,0x1f,0xbf,0x5d,
	0x19,0x2b,0x8f,0xb7,0xff,0xed,0xba,0x8f,
	0x2f,0x04,0x3f,0xb3,0x23,0xfe,0xf9,0xee,
	0xbb,0x2f,0x06,0x3a,0xb7,0xfd,0xdd,0x75,
	0xdf,0x87,0x87,0x5d,0x6f,0x2a,0x7d,0xf2,
	0x2f,0x67,0x3f,0xb2,0x21,0x3f,0xe7,0xe7,
	0xfe,0x7e,0x1e,0x3f,0x30,0x3e,0x0e,0x3f,
	0xbb,0xc9,0x5d,0xa1,0x65,0x31,0x76,0xf6,
	0x0b,0xff,0x5b,0xcf,0xbb,0x8b,0x1f,0x7f,
	0x1f,0xe7,0xfc,0x7f,0x82,0x3f,0x30,0x3d,
	0xcc,0x30,0x89,0xbb,0x24,0x29,0x24,0x20,
	0x8f,0x98,0x00,0xff,0x0f,0x30,0x4e,0xee,
	0x3f,0xfb,0xb3,0x7f,0x87,0xe7,0xf0,0x1d,
	0x3f,0x30,0x4c,0x99,0xcf,0x07,0x4f,0xb2,
	0x21,0xee,0xde,0x57,0x3f,0x31,0x4f,0xfb,
	0x3f,0xbb,0x7f,0xc0,0x67,0x01,0xfe,0xba,
	0x29,0xc4,0x00,0x16,0x1f,0x4e,0xcf,0xe0,
	0x69,0x70,0x87,0x0c,0x4c,0x53,0x3f,0xf4,
	0x4f,0x1e,0xa3,0x44,0xf0,0x00,0x07,0xfe,
	0x42,0xd9,0xba,0x4f,0x2f,0x5f,0x78,0xea,
	0x2f,0x53,0x5f,0x9e,0x48,0x0f,0xfe,0x00,
	0x3f,0x11,0x5a,0x00,0x5c,0x5f,0xbc,0x5a,
	0x14,0xa4,0x88,0x24,0x21,0x5f,0x5d,0x5f,
	0x0b,0x50,0x2b,0x81,0x01,0x0e,0x77,0x5f,
	0xec,0x5f,0x9b,0x5d,0x0e,0x6f,0x20,0x6f,
	0x3f,0x42,0x0b,0x63,0xf8,0x42,0xd9,0x02,
	0x2d,0x4d,0x62,0xfd,0xe3,0xfc,0x38,0x70,
	0x50,0x70,0x4c,0x72,0x6f,0x84,0x6f,0x3f,
	0x41,0xe3,0x38,0x6f,0xee,0x88,0x6f,0x1e,
	0x5d,0x60,0xdd,0xfb,0xd7,0xb7,0x6f,0xf9,
	0x70,0x6f,0xe5,0x6f,0x8e,0x66,0xc4,0xfb,
	0xff,0x07,0x9e,0x6f,0x13,0x7f,0xc2,0x67,
	0xf0,0x0c,0xb6,0xd0,0x84,0x26,0xf2,0xba,
	0xa5,0xba,0x4b,0x7f,0x56,0x0f,0x0c,0x7f,
	0x7a,0x1e,0x79,0xdf,0x2b,0x7d,0xb7,0xff,
	0xec,0xb2,0xbb,0x3f,0x20,0xb4,0x7f,0xb8,
	0x70,0xc4,0x01,0x6a,0x7f,0x7c,0x7f,0xdc,
	0x63,0x6d,0xe7,0xb0,0x91,0xb2,0x4b,0x5f,
	0x18,0x8f,0xc7,0x7f,0xfc,0x9e,0x1d,0x5a,
	0x64,0xfb,0x7b,0xdb,0xf7,0xc8,0x6c,0xf7,
	0xff,0xec,0xaa,0x07,0x8f,0xcc,0x7c,0x8f,
	0x4f,0x2f,0xfc,0xef,0x36,0x10,0x42,0x8f,
	0xff,0xfb,0x05,0xd7,0x57,0x82,0x80,0xc6,
	0x04,0x54,0xa3,0x6a,0x8f,0xdf,0x8f,0x8e,
	0x8f,0x87,0xff,0xfc,0xf6,0xa3,0x8f,0xb5,
	0x83,0xc7,0x62,0xc0,0x88,0x8f,0x90,0xcc,
	0x8f,0x41,0x9f,0xf0,0x8f,0x52,0x41,0xf9,
	0x49,0x9f,0x25,0x10,0x3f,0x23,0xfb,0xd8,
	0x63,0x63,0xa5,0xb4,0x7c,0x43,0x9a,0x33,
	0x9f,0xa8,0x9f,0x02,0xac,0x90,0xf7,0x8b,
	0x1d,0xce,0x9f,0xdb,0x99,0x89,0x9b,0xa3,
	0x7f,0x0c,0xaf,0x8c,0xbb,0x9f,0xbd,0xb0,
	0xf8,0x00,0x10,0xaf,0xe4,0x9f,0xfa,0x00,
	0xf1,0x08,0x3e,0x7f,0x6f,0xaf,0x74,0xa1,
	0xc1,0x23,0xaf,0x35,0xaf,0x47,0xaf,0xa3,
	0xaf,0x00,0xce,0xaf,0x19,0xaf,0xc7,0x9f,
	0x04,0xbf,0xb3,0xaf,0x28,0xbf,0x3a,0xbf,
	0xe9,0xaf,0x40,0x5e,0xbf,0x0d,0xbf,0x1f,
	0xbf,0x94,0xbf,0x4f,0x9f,0x4d,0x48,0xc0,
	0x20,0x5f,0x04,0x73,0xbf,0x95,0x01,0xe3,
	0x9a,0x0f,0xff,0xbf,0x22,0x1f,0xc0,0xbf,
	0xd2,0xbf,0x02,0x90,0x06,0xed,0xee,0xbf,
	0x63,0xcf,0x12,0xcf,0x54,0x4f,0x36,0xcf,
	0x80,0xb4,0x81,0x83,0x98,0x0f,0xc5,0xcf,
	0x60,0x7f,0x86,0xcf,0x98,0xcf,0xda,0x49,
	0xee,0x40,0xfb,0x9f,0x2c,0xdf,0xdb,0xcf,
	0xed,0xcf,0xff,0xcf,0x81,0xb3,0xd7,0x1c,
	0x4f,0x24,0x8d,0xdf,0x98,0xd7,0xde,0x47,
	0xdf,0x98,0xd6,0x80,0xc4,0x00,0x3e,0x14,
	0x00,0xc3,0x01,0x71,0xdb,0xb7,0xcf,0xf4,
	0xdf,0xa3,0xdf,0xb5,0xdf,0xc7,0xdf,0x81,
	0xb3,0xe1,0xe7,0xe0,0xdf,0x55,0xef,0x3d,
	0xd7,0xda,0x51,0xfb,0x83,0x00,0x93,0x60,
	0x83,0x17,0xef,0x54,0xd2,0xcf,0xad,0xb6,
	0xcc,0x68,0xe7,0xf0,0x50,0xcf,0xb9,0xef,
	0x3d,0xd7,0x0e,0xe1,0xfb,0xbb,0xff,0x6e,
	0x21,0xbb,0x7b,0xe7,0x6f,0xf6,0x8e,0xef,
	0xe4,0xb7,0x82,0x7f,0xdf,0x20,0xff,0x02,
	0x28,0xf4,0x5e,0xd7,0xe9,0x63,0x23,0xe9,
	0xef,0x97,0xed,0x6e,0xff,0x80,0xff,0x0e,
	0x2f,0xfc,0xeb,0x83,0x00,0xdd,0xe3,0xff,
	0x13,0x4d,0xff,0x5f,0xff,0x68,0xd4,0xff,
	0xe6,0xff,0xf0,0xf6,0x9e,0x9f,0xf1,0xbb,
	0xff,0x79,0xe3,0x0f,0xfc,0x3f,0x9f,0xe1,
	0xde,0x31,0xb3,0xff,0xc5,0xff,0x3a,0x0f,
	0x0c,0x4c,0x0f,0xfb,0xf8,0xf2,0xbb,0x33,
	0x02,0x35,0x13,0x42,0x41,0x17,0x0f,0x8e,
	0x99,0xeb,0xcf,0xff,0xfb,0x5e,0xaf,0xaf,
	0x0f,0x06,0xe9,0xf1,0x39,0x83,0x2a,0x12,
	0x51,0xd0,0x80,0x00,0x0f,0xd2,0x54,0x7e,
	0x0f,0xc6,0xd8,0x4a,0xfb,0xd6,0x1b,0xdf,
	0x14,0x1f,0x3f,0xd8,0xfb,0xbb,0x73,0xf7,
	0xf8,0x19,0x20,0x51,0xd0,0xf0,0x00,0x7f,
	0xdb,0x0f,0xe0,0xed,0x0f,0xff,0x00,0xaa,
	0xef,0x77,0x1f,0x3e,0xd9,0xe0,0xbb,0xb6,
	0x01,0xfb,0x67,0x10,0x5d,0xb3,0x6e,0x51,
	0x43,0x1f,0xfd,0xed,0x65,0x1f,0xda,0x1f,
	0x8e,0x25,0x1b,0x83,0xb7,0x7b,0x9a,0x19,
	0x42,0x1f,0x8c,0x0f,0xd6,0x38,0xcb,0x1f,
	0x40,0x2f,0x27,0x19,0xff,0x77,0x78,0x36,
	0x13,0x33,0x68,0x00,0x0f,0x2f,0xbd,0x1a,
	0x4a,0x5f,0xa3,0x2f,0x3e,0xdf,0x9c,0x15,
	0x9b,0x64,0x52,0xd2,0x11,0xfe,0x7c,0xc0,
	0xdd,0x24,0xf3,0x0c,0xfe,0x93,0x2f,0x08,
	0x3f,0xb7,0x29,0x07,0x1f,0xf0,0xd9,0x5a,
	0xb6,0xfe,0x65,0xd7,0x2f,0xe9,0x2b,0x03,
	0x1f,0x3c,0x6c,0x3f,0xb7,0x28,0xfe,0xed,
	0x6f,0xd6,0xc8,0x60,0xa9,0xf0,0x13,0x00,
	0x00,0x31,0x74,0x39,0x35,0x7f,0x7a,0x25,
	0x5d,0xb7,0xa8,0x52,0xe3,0xe0,0xfe,0x9f,
	0x0f,0xd0,0x3f,0x7f,0x39,0xe3,0x6f,0xb6,
	0x0c,0x34,0x00,0x91,0x3a,0xfc,0x7c,0xa0,
	0x3f,0x2e,0x0f,0x27,0x4f,0x39,0x4f,0x6e,
	0x44,0xd4,0x0f,0xb7,0xb8,0x16,0xed,0xfb,
	0xbc,0x51,0x40,0xe0,0x07,0x4f,0x19,0x4f,
	0x8e,0x4f,0x3d,0x4f,0x80,0x41,0xef,0xbf,
	0xbe,0x0e,0x16,0xed,0xbb,0xbb,0x7f,0x08,
	0x90,0x6c,0x4f,0x7e,0x4f,0xf3,0x4f,0x38,
	0xa2,0x4f,0xb4,0x4f,0x04,0x51,0xbf,0xbb,
	0x7f,0x2c,0xe0,0xd0,0x4f,0x62,0x56,0xa4,
	0xee,0x9e,0x0f,0x5f,0x5f,0x7e,0x3a,0x01,
	0xd0,0xb9,0x4d,0x03,0xfe,0x0b,0x2f,0x5f,
	0xdd,0x47,0x93,0x90,0x02,0x1f,0xc3,0x5f,
	0x0e,0x5b,0x75,0xdf,0xb9,0x44,0xef,0x81,
	0xe6,0xb8,0x77,0xbf,0xcd,0x4f,0xe2,0xdf,
	0x45,0xdf,0x44,0xef,0x25,0x6f,0x7c,0x3c,
	0x03,0x03,0xb0,0x04,0x7d,0xb0,0xe9,0x5a,
	0xbb,0x57,0x80,0x6a,0x4f,0x0c,0x66,0xa9,
	0xef,0x8a,0x6f,0x0a,0xd5,0x5d,0xde,0x16,
	0xe3,0x83,0x5d,0x47,0x57,0x82,0x60,0x6f,
	0xe2,0x42,0x87,0xef,0xff,0xe1,0x2e,0x2f,
	0xef,0x6f,0x9e,0x6f,0xe8,0x5b,0xf8,0x11,
	0x2f,0xb3,0x51,0xc4,0x6f,0x62,0x84,0xee,
	0x92,0x2f,0x53,0x7f,0xb6,0x2f,0x00,0xe8,
	0x5b,0x68,0x75,0x2a,0x7f,0x00,0x83,0xf6,
	0x2f,0xb7,0x7f,0x66,0x7f,0x7c,0xef,0x00,
	0x8a,0x7f,0x9c,0x78,0xb3,0x5f,0x1c,0x8f,
	0xcb,0x7f,0xdd,0x7f,0xef,0x7f,0xb5,0x35,
	0x01,0xe1,0xbe,0x3f,0x7f,0x8f,0x2e,0x8f,
	0x40,0x8f,0x52,0x8f,0xe0,0x4f,0xd9,0x8f,
	0x80,0xeb,0x8f,0x9a,0x8f,0xac,0x8f,0xbe,
	0x8f,0x33,0x9f,0x45,0x9f,0x74,0xca,0xfb,
	0x3f,0xed,0xeb,0xe0,0x63,0x06,0xf7,0x92,
	0x31,0x29,0xcd,0xf0,0x1c,0x9f,0x2e,0x9f,
	0xa3,0x9f,0x52,0x9f,0xff,0xfb,0x6d,0xed,
	0xc7,0xd7,0xdd,0x7e,0x6b,0x9f,0x7d,0x9f,
	0xd3,0x67,0xf1,0x8f,0x70,0xb1,0x9f,0x10,
	0xaf,0xaf,0xb7,0xc9,0x90,0xdb,0xdd,0xbe,
	0xcf,0x90,0xfe,0x15,0xaf,0xfe,0x7e,0x00,
	0xff,0xc0,0x0f,0xf0,0x67,0x03,0xff,0x00,
	0x03,0x40,0xd1,0x69,0xee,0xb7,0x36,0xaf,
	0xfc,0x74,0xaf,0xaf,0xb7,0xfa,0xac,0x0e,
	0xbd,0xfd,0xde,0x1d,0x07,0x34,0xaf,0xff,
	0xff,0x7e,0x49,0xaf,0x5b,0xa4,0xde,0xe0,
	0xe8,0xc8,0xaf,0xda,0xaf,0xb1,0xb2,0x1e,
	0x8f,0xa0,0xae,0xdf,0x7e,0xa7,0xf3,0xef,
	0x6f,0x98,0xaf,0xaa,0xa0,0x40,0x41,0x35,
	0x04,0xc4,0x12,0x60,0xd2,0x68,0xef,0xc6,
	0xaf,0x3b,0xbf,0xae,0xb4,0xfe,0xee,0x5e,
	0xf3,0xa1,0xde,0xbf,0x7d,0xf7,0xfb,0xa0,
	0xf0,0x94,0x9e,0xc0,0x10,0xbf,0x22,0xbf,
	0x97,0xbf,0xa2,0xb7,0x8e,0x30,0x53,0xb3,
	0xf9,0xce,0xaf,0xdd,0xd7,0x5d,0x77,0xfb,
	0xa0,0xf7,0xff,0xaf,0x4f,0x86,0xa2,0xb5,
	0xe4,0xfe,0xa6,0x15,0x88,0xbf,0xfd,0xbf,
	0xac,0xb7,0x3f,0xb7,0xe7,0xfe,0x7f,0xba,
	0xb1,0xcf,0x3d,0xc0,0xb0,0x9f,0x07,0xff,
	0xfc,0xfb,0xc7,0xbf,0xd9,0xb8,0x80,0xba,
	0xc5,0xaf,0x66,0xcf,0xde,0xe6,0xe2,0x1f,
	0xe7,0xfc,0x7f,0x02,0x00,0xfb,0xef,0x0f,
	0x3b,0xe8,0xe3,0x8f,0x27,0xc0,0x4a,0xf0,
	0x2d,0xcf,0xdb,0xb5,0xa3,0xff,0x5f,0x91,
	0x09,0x61,0xaf,0xca,0xcf,0xff,0x13,0x01,
	0x07,0x27,0xe7,0xf0,0xff,0x56,0xb0,0xc1,
	0x26,0xfe,0x8f,0xcf,0xa1,0xcf,0x70,0xf7,
	0x9f,0x28,0xdf,0x30,0xd4,0x77,0x01,0xc0,
	0xe7,0x81,0x55,0xb1,0x04,0xc1,0x27,0x94,
	0x9d,0xfc,0x04,0xd9,0x81,0xe5,0x94,0x9f,
	0x8d,0xdf,0x3c,0xd5,0x5f,0xbb,0x7f,0xf0,
	0x00,0x07,0x49,0xda,0xf7,0x63,0xbf,0x10,
	0x69,0xdf,0x7b,0xdf,0xf0,0xdf,0x9f,0xd8,
	0xfe,0x38,0xe0,0xf2,0xa0,0xb1,0xdf,0x00,
	0xcc,0xe7,0x05,0xd8,0x80,0xb8,0xf8,0xd1,
	0x0f,0xff,0xf9,0xdf,0xa4,0x14,0xfe,0x89,
	0xf1,0xf8,0x37,0xaf,0x05,0xd8,0x8c,0x97,
	0xef,0xee,0xef,0xf1,0x07,0xee,0xeb,0xb2,
	0xa7,0x7f,0x5f,0xef,0xe0,0xd2,0xbe,0x2e,
	0xf1,0x8b,0x3c,0x75,0xb8,0xa0,0xea,0xee,
	0xef,0x1b,0xad,0xb1,0xef,0x33,0xde,0xf0,
	0xdf,0xd3,0xda,0xef,0xec,0xef,0xfe,0xef,
	0xef,0xee,0xee,0xfb,0x80,0x14,0xff,0x26,
	0xfe,0xd0,0x24,0x3e,0xff,0xf2,0x8f,0xa9,
	0xfb,0xa8,0xe2,0xfd,0x07,0xef,0x3b,0xb1,
	0x79,0xff,0xcf,0xcd,0x34,0x34,0xa2,0xff,
	0xb4,0xfa,0xfc,0x41,0x3f,0xdf,0xd0,0xe1,
	0xee,0xef,0xfb,0xee,0xdb,0x0c,0x78,0xff,
	0x51,0x0f,0xff,0xff,0x60,0x91,0x06,0x0f,
	0x18,0x0f,0x46,0x3d,0x7f,0xee,0xee,0x1f,
	0xf7,0xef,0x28,0x73,0x41,0x0f,0x00,0xb6,
	0x0f,0x65,0x0f,0xda,0x0f,0xec,0x0f,0x9b,
	0x01,0x05,0x20,0x0c,0x71,0xee,0x0f,0x00,
	0x1b,0x1f,0x26,0xa4,0xd1,0x0f,0x46,0x1f,
	0xf5,0x0b,0x5f,0xa0,0x09,0x10,0x09,0x1f,
	0x00,0x7e,0x1f,0x2d,0x1f,0xa2,0x1f,0xb4,
	0x1f,0x37,0x01,0x1b,0xd0,0x6a,0x1f,0xdf,
	0x1f,0x00,0x8e,0x1f,0xa0,0x1f,0x15,0x2f,
	0xdc,0xdf,0x39,0x2f,0xe8,0x1f,0xfa,0x1f,
	0x6f,0x2f,0x10,0x1e,0x2f,0x93,0x2f,0xa5,
	0x2f,0xac,0x23,0xf7,0x5b,0x2f,0xd0,0x2f,
	0x7f,0x2f,0x00,0xe2,0x26,0x0b,0x82,0xf2,
	0xc0,0x0b,0x8f,0xb4,0x2f,0xc6,0x2f,0x3b,
	0x3f,0xa2,0xa8,0xff,0xec,0x61,0xce,0x1c,
	0x7f,0xc7,0x1a,0xae,0xff,0xff,0xb8,0xff,
	0xc7,0x08,0x7f,0xce,0xfe,0xc4,0x7a,0x6f,
	0x74,0x38,0xc1,0x23,0x3f,0x98,0x3f,0x47,
	0x3f,0xeb,0xaf,0xff,0xb6,0xfb,0xbf,0xba,
	0xea,0xb5,0xff,0xbb,0x3f,0x7f,0xba,0xeb,
	0xbf,0xb6,0x1e,0x69,0x3f,0x17,0x3f,0xb8,
	0x8d,0x3f,0x02,0x4f,0xb1,0x3a,0xb7,0xb7,
	0x7b,0xc1,0x30,0xbb,0x19,0xff,0x24,0x40,
	0xc9,0x30,0xee,0xee,0xc6,0xbf,0xe0,0x3f,
	0xf2,0x3f,0xfc,0x67,0x4f,0xa2,0xa8,0xdf,
	0x77,0xf7,0x7b,0xff,0xbe,0x1e,0x27,0x42,
	0xf6,0xeb,0xbf,0xf6,0x30,0x4f,0xb6,0x9f,
	0x00,0x97,0xf0,0x89,0x02,0xe4,0xb5,0xce,
	0x4f,0xa5,0xa5,0x1e,0xfb,0xcf,0xbb,0xff,
	0xff,0xbe,0xe9,0x35,0xff,0x7b,0xa1,0xee,
	0x07,0xeb,0xbf,0xc6,0x94,0x4f,0xa6,0x4f,
	0xb8,0x4f,0x2d,0x5f,0xa0,0xaa,0xaf,0xed,
	0xfd,0xf7,0xdb,0xed,0x40,0x2e,0x29,0x40,
	0xde,0x1f,0xe8,0x7f,0xb6,0x1e,0xe1,0xfa,
	0x4f,0xb2,0xff,0x56,0x4a,0xf8,0xe6,0x94,
	0x95,0x5f,0xb4,0x37,0xad,0xb6,0xdb,0xbf,
	0xba,0x1b,0xe9,0x3f,0x29,0x40,0xbb,0xfb,
	0xa2,0x70,0x3e,0x70,0xc3,0x5f,0x30,0x72,
	0x5f,0x84,0x5f,0xf9,0x5f,0xa8,0x5c,0xeb,
	0xbf,0xc5,0x30,0xbc,0x51,0x89,0xfe,0xd0,
	0x1f,0x34,0x6c,0xbe,0xe3,0x5f,0x58,0x6f,
	0x9f,0xab,0x1c,0x7f,0x73,0xcf,0x3c,0x7f,
	0xc7,0x1b,0xbf,0x61,0x31,0xc7,0xfb,0xff,
	0xcf,0x24,0x6f,0x36,0x6f,0x00,0x97,0xfb,
	0xc7,0x40,0x54,0x6f,0xc9,0x6f,0xf4,0x2c,
	0xe3,0x68,0xf5,0x6f,0xa4,0x6f,0xfb,0x56,
	0xc1,0x00,0xbb,0x6f,0xcd,0x6f,0x42,0x7f,
	0x54,0x7f,0x03,0x7f,0x15,0x7f,0x8a,0x7f,
	0x39,0x7f,0x00,0xae,0x7f,0xc0,0x7f,0x6f,
	0x7f,0x81,0x7f,0x93,0x7f,0xf6,0x7f,0x1a,
	0x8f,0xc9,0x7b,0x02,0x89,0x07,0x00,0xe2,
	0x7f,0x57,0x8f,0x06,0x8f,0x7b,0x8f,0x2a,
	0x8f,0x3c,0x88,0x41,0x87,0x48,0x8f,0xbd,
	0x8f,0x6c,0x8f,0xe1,0x8f,0xd5,0x5b,0x3f,
	0xef,0x88,0x01,0xfb,0xb4,0xb0,0xae,0x8f,
	0xc0,0x8f,0x35,0x9f,0x47,0x9f,0xa8,0xbc,
	0x54,0x96,0x03,0xe3,0xdb,0x10,0x9f,0x85,
	0x9f,0x34,0x9f,0xa9,0x9f,0xbb,0x9f,0x06,
	0x96,0x00,0x27,0xa0,0x76,0x9f,0x88,0x9f,
	0xfd,0x9f,0x0f,0xaf,0x21,0xaf,0x2d,0xa8,
	0xdb,0x9f,0x00,0xed,0x9f,0x62,0xaf,0x74,
	0xaf,0x86,0xaf,0x35,0xaf,0xaa,0xaf,0x59,
	0xaf,0xce,0xaf,0x08,0xe0,0xaf,0xf2,0xaf,
	0xa1,0xa2,0x1f,0x02,0x99,0xb3,0xaf,0x16,
	0xbf,0x3a,0xbf,0x3c,0x4c,0xbf,0x59,0xb9,
	0x87,0xff,0xfe,0xef,0x0b,0xbf,0x1d,0xbf,
	0x10,0x92,0xbf,0xa4,0xbf,0xb6,0xbf,0xbd,
	0xb3,0x03,0x9d,0x00,0xee,0x6f,0x81,0xbf,
	0xf0,0xf6,0xbf,0x08,0xcf,0x1a,0xcf,0x20,
	0xc2,0x80,0x00,0x07,0xef,0x40,0xd2,0xbf,
	0xe4,0xbf,0x59,0xcf,0x6b,0xcf,0x7d,0xcf,
	0x2c,0xc6,0x82,0x36,0xcf,0x1e,0x48,0xcc,
	0xdf,0xff,0xf2,0xba,0x6f,0xbf,0xd0,0xcf,
	0xe2,0xcf,0x32,0xc9,0xb6,0x1d,0x8a,0x6f,
	0xad,0xcd,0xec,0xb2,0x9b,0xcf,0x34,0xdf,
	0x4c,0x46,0xdf,0x65,0xb5,0xee,0xfd,0xff,
	0xcf,0xad,0xcd,0xee,0xb0,0xef,0xe0,0x97,
	0xdf,0xa9,0xdf,0xd9,0x57,0x62,0xdf,0x48,
	0xcc,0xef,0xff,0xec,0xa1,0xaa,0xc7,0xdf,
	0xfc,0xdf,0x0e,0xef,0xda,0x56,0x0b,0xc2,
	0x5c,0xfd,0x02,0xd7,0xdf,0xef,0xea,0xdf,
	0x5f,0xef,0x71,0xef,0x83,0xef,0x32,0xef,
	0x44,0xef,0xf0,0xb9,0xef,0xcb,0xef,0xdd,
	0xef,0xeb,0xea,0xf0,0xff,0xc3,0x94,0xbf,
	0x3f,0x8c,0x3a,0xef,0xf5,0xf5,0x4b,0xc9,
	0xf7,0x07,0xff,0xee,0x9a,0xb3,0xef,0x28,
	0xff,0x3a,0xff,0x4c,0xff,0x4c,0x40,0xff,
	0x7f,0xbd,0x65,0xdf,0x75,0xda,0xef,0xed,
	0x81,0xb6,0x07,0xfd,0x23,0xdf,0x8c,0xff,
	0x9e,0xff,0xb0,0xff,0x4c,0x40,0xbf,0x3b,
	0xbd,0x75,0x65,0xff,0x87,0xff,0xf1,0xbe,
	0xcf,0xef,0xff,0x68,0x01,0x0f,0x13,0x0f,
	0xc2,0xf2,0xfd,0xc8,0xf2,0xdd,0x57,0x54,
	0xc6,0x60,0x54,0xcf,0x4d,0x0f,0x5f,0x0f,
	0x71,0x0f,0x45,0x47,0xa0,0xe3,0xc8,0xf1,
	0x81,0x6f,0x31,0x0f,0xa6,0x0f,0xb8,0x0f,
	0xca,0x0f,0xdc,0x0f,0xc3,0xf1,0xdf,0x1f,
	0x74,0x3f,0x0c,0x3a,0x9f,0x95,0x0f,0x0a,
	0x1f,0x1c,0x1f,0xd8,0x2e,0x1f,0x40,0x1f,
	0xc3,0xf1,0xbf,0xfd,0x03,0x11,0xdc,0xe7,
	0xfe,0xfb,0x09,0xcf,0xff,0xfb,0xef,0xfb,
	0xa0,0xab,0x43,0x1e,0xe0,0x43,0x1f,0x85,
	0x1f,0x97,0x1f,0x52,0xff,0xfd,0xbe,0x51,
	0x6b,0xec,0xe6,0x4b,0xc9,0xb7,0x6c,0x11,
	0xaf,0xaa,0xcd,0x3f,0xf8,0xe7,0x1f,0xf9,
	0x1f,0xec,0xef,0xff,0xc3,0xfd,0xff,0xcf,
	0x0f,0xfb,0xff,0xed,0xf6,0xc3,0x1f,0xd5,
	0x1f,0x4a,0x2f,0x5c,0x2f,0x70,0x6e,0x2f,
	0x46,0x46,0x9e,0xe7,0x30,0x23,0xd7,0xfb,
	0x6f,0x39,0x2f,0xa0,0xae,0x2f,0xc0,0x2f,
	0xd2,0x2f,0xe4,0x2f,0x03,0x11,0x8f,0x98,
	0x20,0xf8,0x0f,0x61,0x92,0xee,0xe1,0xe6,
	0x2f,0x15,0x3f,0x27,0x3f,0x39,0x3f,0x18,
	0xe8,0x2f,0x65,0x90,0x99,0x20,0xaf,0x92,
	0x9e,0x2f,0x77,0x3f,0x89,0x3f,0xfe,0x9b,
	0x3f,0xff,0xfd,0xe3,0xfb,0xf0,0xdf,0x07,
	0x04,0x49,0xcb,0x33,0x20,0xbb,0x63,0x3f,
	0xd8,0x3f,0xea,0x3f,0xfc,0x3f,0x9a,0xe2,
	0x4f,0xdd,0xfb,0xef,0x6f,0x04,0x19,0xc0,
	0x36,0xba,0xca,0x3f,0xc0,0x3f,0x4f,0x51,
	0x4f,0x63,0x4f,0x12,0x43,0x66,0x99,0x68,
	0x12,0xe0,0xbb,0x1f,0xf8,0x60,0xbb,0x18,
	0x20,0xda,0x56,0x3b,0x88,0xa7,0x4f,0x30,
	0xb9,0x4f,0x3c,0x82,0x04,0x17,0x13,0x40,
	0xff,0x77,0x7b,0xf9,0x04,0x1f,0x70,0xfd,
	0x4f,0x0f,0x5f,0x21,0x5f,0x08,0x4a,0xf8,
	0x78,0xf7,0x2f,0x49,0x60,0xec,0x4f,0x61,
	0x5f,0x73,0x5f,0x85,0x5f,0xa4,0x3b,0xb7,
	0xfb,0xc2,0x59,0xe0,0x50,0x5f,0xc5,0x5f,
	0xd7,0x5f,0xe9,0x5f,0x93,0xea,0xfb,0xaf,
	0xfb,0x3d,0x77,0x7d,0x4d,0xee,0x82,0xe8,
	0xfb,0xf5,0x5f,0x32,0x6f,0xe8,0x44,0x6f,
	0x56,0x6f,0x05,0x63,0x7d,0x0c,0x6c,0xb7,
	0xff,0xee,0x87,0xbe,0xeb,0x7b,0x59,0x6f,
	0x96,0x6f,0xa8,0x6f,0xba,0x6f,0xff,0x7f,
	0xff,0xe0,0x3f,0xf8,0x70,0xfd,0x8f,0x71,
	0x6f,0x01,0x0b,0x47,0x81,0xeb,0x6f,0xfd,
	0x6f,0x0f,0x7f,0xad,0x5f,0xfe,0x81,0x1d,
	0x7c,0x1f,0xf7,0xff,0xed,0xbe,0xeb,0xe8,
	0x6f,0x5d,0x7f,0x6f,0x7f,0x38,0x1e,0x7f,
	0x93,0x7f,0x2e,0x24,0xe1,0x87,0x5b,0x4c,
	0x7f,0xc1,0x7f,0xf0,0xd3,0x7f,0x82,0x7f,
	0xf7,0x7f,0xf6,0x24,0xee,0xbf,0x5b,0xb5,
	0x00,0xfa,0x7f,0x26,0x8f,0x38,0x8f,0xe7,
	0x7f,0x5c,0x8f,0x5b,0x33,0x11,0x8f,0x86,
	0x8f,0x30,0x98,0x8f,0x47,0x8f,0xbc,0x8f,
	0x6b,0x89,0xbb,0x6e,0xc2,0x8f,0xee,0x8f,
	0xf0,0x00,0x9f,0xaf,0x8f,0x24,0x9f,0xd7,
	0xf3,0xe1,0x83,0xb8,0xee,0x00,0x26,0x9f,
	0x52,0x9f,0x64,0x9f,0x13,0x9f,0x88,0x9f,
	0x80,0x9f,0xac,0x9f,0xbe,0x9f,0x00,0xd0,
	0x9f,0x9a,0x9f,0xda,0x9f,0x06,0xaf,0x18,
	0xaf,0x2a,0xaf,0xf4,0x9f,0x4e,0xaf,0x80,
	0x46,0xab,0x9e,0xe5,0x49,0xaf,0x88,0xaf,
	0x9a,0xaf,0x77,0xaf,0x3b,0x7c,0x83,0xff,
	0xbf,0xfb,0xba,0x3f,0xfb,0xb6,0x1f,0xfe,
	0x0f,0xff,0xfb,0xb3,0xcf,0x7c,0x49,0xe6,
	0xaf,0xf8,0xaf,0xa7,0xaf,0xfc,0x02,0xbf,
	0x47,0x70,0xbf,0xbf,0xfb,0xd6,0xdf,0xfb,
	0x1b,0xb6,0xef,0x07,0x60,0xad,0xb7,0xdb,
	0xaf,0x50,0xbf,0x62,0xbf,0xdc,0x11,0xbf,
	0x6c,0xb9,0x83,0xff,0xeb,0x32,0xb0,0xee,
	0xef,0xff,0xf7,0xae,0xef,0xfb,0xff,0xfd,
	0x6d,0xb7,0x40,0x7b,0xff,0xb4,0xbf,0xc6,
	0xbf,0x75,0xbf,0x27,0x2b,0x95,0xb6,0xf7,
	0x9f,0xbf,0xf0,0x14,0xcf,0x26,0xcf,0xd5,
	0xbf,0x30,0xcd,0xd7,0xff,0xe7,0x87,0xfe,
	0x33,0xb0,0xef,0xf7,0x9e,0x1f,0xef,0x87,
	0xfe,0xc3,0xe3,0xcf,0x07,0xcf,0x7c,0xcf,
	0x8e,0xcf,0x3d,0xc9,0xc0,0x0f,0xbe,0x4b,
	0xcf,0xeb,0xbf,0x5f,0xfb,0xba,0xfe,0xb4,
	0x6f,0x70,0x06,0xcf,0xdf,0xcf,0xf1,0xcf,
	0x3c,0xc9,0xf0,0x1f,0xe0,0xdf,0xfa,0x8a,
	0x3d,0xc0,0xe7,0xc0,0xc2,0xfe,0x9a,0xbf,
	0xef,0xec,0xcb,0x47,0xf8,0xc7,0x00,0x00,
	0x01,0xf5,0xcf,0x83,0x24,0xd9,0xf1,0xff,
	0xc7,0x3e,0x14,0xde,0xed,0xbe,0xef,0xfb,
	0xfe,0x36,0xbf,0x3c,0xdf,0xec,0x4e,0xdf,
	0x60,0xdf,0xff,0xfc,0x3d,0xc0,0xf0,0xff,
	0xff,0x3d,0xc1,0x3b,0x7c,0x82,0xef,0xe0,
	0xfe,0xd2,0xaf,0x00,0xeb,0x89,0xf3,0x97,
	0x43,0x3d,0xc1,0xf9,0x1b,0xe2,0xbf,0xdf,
	0x6d,0xd3,0xf1,0x06,0x99,0x41,0x3f,0xff,
	0x33,0xd7,0x64,0xaf,0x3c,0xcf,0x0c,0xef,
	0x1e,0xef,0x0c,0x68,0xd8,0x77,0xd2,0x8f,
	0xff,0x2f,0x47,0x5f,0xef,0xc1,0xef,0x70,
	0xef,0x28,0x82,0xe9,0xb0,0xe4,0x69,0xd7,
	0x1f,0xc8,0xe1,0xe3,0x70,0xd1,0xa9,0xef,
	0xe0,0x57,0xef,0xcd,0xef,0xdf,0xef,0xf1,
	0xee,0x44,0xf2,0xff,0xf8,0xff,0x68,0x20,
	0x67,0x68,0x12,0xcd,0xa0,0xee,0xd1,0xa2,
	0xff,0xbf,0xf8,0xdf,0xf4,0x36,0xff,0x80,
	0xe1,0xf8,0xd0,0x40,0xfc,0x3f,0xf0,0xe5,
	0xbf,0x0f,0xe7,0x0e,0xbb,0xfd,0x7d,0x66,
	0xd9,0xf8,0x68,0x3f,0xf4,0x8a,0x2c,0x31,
	0xb0,0xee,0x35,0xb2,0xff,0xdf,0x94,0xdf,
	0xfc,0x9a,0xff,0xac,0xf5,0xfd,0xdf,0xef,
	0x59,0x77,0xdb,0xaf,0x76,0xbb,0xfb,0x7e,
	0x24,0xf8,0xc7,0x3e,0xf3,0xff,0x6b,0x1f,
	0xdd,0xeb,0xbe,0xee,0x99,0xb2,0xff,0xef,
	0x30,0xdf,0xf8,0xfe,0xff,0x80,0xe2,0x44,
	0xf0,0xfd,0xef,0xef,0x5d,0x77,0x55,0xfd,
	0x1e,0x0c,0xf7,0xa8,0x54,0xdf,0x36,0x0a,
	0xf7,0x94,0xb1,0xc5,0xed,0x49,0x03,0xf7,
	0x50,0x0f,0x62,0x0f,0x74,0x07,0xff,0x5d,
	0x3f,0x77,0xe1,0x76,0xbb,0xf7,0x7f,0x27,
	0xf0,0x27,0xf6,0xd2,0x92,0x05,0xe3,0x7f,
	0x4b,0x5d,0xc0,0xe1,0x61,0xc2,0xe1,0xfb,
	0xf8,0x68,0xcf,0xc6,0x0f,0x74,0x06,0xe8,
	0x38,0xdd,0x77,0xdd,0xef,0x76,0x9b,0xf7,
	0x0f,0xea,0x0b,0xc0,0x7f,0xff,0x19,0x01,
	0x41,0xe8,0xa3,0x05,0x5f,0xee,0xc5,0xc2,
	0x88,0x20,0xcd,0xcf,0xfc,0x2b,0x1f,0x75,
	0x06,0xf7,0xdd,0x0f,0xdd,0x0e,0xa7,0x9e,
	0xe8,0x0d,0x80,0x3f,0xfe,0x00,0x60,0x1c,
	0xf7,0xb1,0x5f,0x61,0xee,0x29,0xd2,0x4e,
	0x0f,0x8c,0x1f,0x72,0x0a,0xff,0x7f,0x36,
	0x00,0x4e,0xe8,0x0d,0x00,0x1f,0xfc,0xc3,
	0x1f,0x89,0xd0,0xee,0x8d,0xd2,0x38,0xea,
	0xff,0xf0,0x1f,0x72,0x08,0xdf,0xef,0x7f,
	0x10,0x21,0x84,0x0a,0x9e,0x21,0x21,0x0f,
	0xfc,0x00,0x7f,0x61,0x1b,0x7b,0xf0,0x82,
	0x03,0xef,0xe1,0xf1,0xd2,0x86,0xff,0x54,
	0x2e,0xcd,0x41,0xbc,0xd0,0x78,0x01,0xae,
	0xb4,0xf0,0xff,0x7f,0xe3,0xf6,0xd0,0x06,
	0x7a,0x2a,0xfe,0x1f,0x00,0x0f,0xf8,0x00,
	0x3f,0x61,0x1b,0x17,0xff,0x10,0x3f,0x00,
	0xbf,0x2f,0x66,0xf3,0xaa,0x33,0x07,0x31,
	0xe1,0x2f,0xf3,0x2f,0xc4,0x69,0xc7,0x43,
	0x08,0xae,0xcb,0x25,0x3f,0x87,0xef,0x03,
	0x4a,0x3f,0x5c,0x3f,0xc6,0x33,0x2f,0x44,
	0xe0,0x2f,0x4c,0x8a,0x3f,0x9c,0x3f,0xae,
	0x3f,0x34,0x96,0xea,0xc7,0x1c,0x0f,0x60,
	0xfe,0x3b,0xbb,0xb0,0x75,0xd8,0x3f,0xea,
	0x3f,0x78,0x01,0xff,0x78,0xfe,0xfa,0x18,
	0x31,0x83,0x8f,0xf8,0xcf,0xf8,0xf7,0xd7,
	0x7f,0x18,0x2d,0x8c,0x2c,0xbf,0xff,0xbf,
	0xea,0xba,0xeb,0xaf,0xfe,0xdb,0x33,0x47,
	0x80,0x3f,0x00,0x00,0x3e,0x03,0x00,0x6f,
	0x44,0x4f,0x6e,0x0b,0xff,0x77,0x7e,0xf5,
	0xeb,0xee,0xbf,0x77,0xf7,0xa7,0x77,0x76,
	0xda,0xb3,0x1b,0x7d,0x4f,0xdf,0x90,0x43,
	0xe8,0xfb,0x3b,0x83,0x35,0x45,0xaa,0xff,
	0x6a,0xbe,0xdb,0xf9,0x55,0xa7,0x4f,0xb9,
	0x4f,0xed,0xee,0xde,0xfb,0xef,0xc3,0xaf,
	0xb6,0x36,0x00,0xc4,0x30,0x8a,0x20,0xbb,
	0x13,0x7f,0xfe,0x3c,0x5f,0x1d,0xf3,0x41,
	0xef,0x6f,0xfe,0xeb,0x33,0x47,0x05,0x51,
	0xd1,0x03,0x0a,0x5f,0x1c,0x5f,0x3b,0x20,
	0xee,0x32,0x50,0xb5,0x5d,0xf2,0x37,0x5a,
	0xe0,0x0f,0x41,0x61,0x1b,0xef,0xff,0xe4,
	0xba,0xbf,0xee,0xe1,0xfe,0xed,0x7b,0xd7,
	0xc6,0x34,0xe8,0xe6,0xb1,0xd0,0x07,0x8f,
	0xa6,0x4f,0x80,0x5f,0x0f,0x1f,0x79,0x3f,
	0xf6,0xff,0xef,0xef,0xb5,0x5a,0xeb,0x0f,
	0x61,0x1d,0xef,0xe4,0xba,0xed,0xef,0xc1,
	0x58,0xeb,0xd5,0x55,0xe7,0x55,0x76,0x23,
	0x6e,0x5f,0xfc,0x1d,0x78,0xfe,0xf6,0x17,
	0xff,0xbe,0xfa,0xfa,0x51,0x57,0x6f,0x4a,
	0x0c,0x6f,0xe2,0x60,0xc9,0xe4,0x92,0x41,
	0x26,0x6c,0xab,0x36,0x6f,0xfc,0x1d,0x7f,
	0xfe,0x6f,0xf5,0xfb,0xae,0xba,0x32,0x50,
	0xb3,0x9f,0xc2,0x32,0x17,0xe0,0x00,0x1f,
	0xc7,0x20,0x07,0xa7,0xc4,0xbc,0xd7,0xdc,
	0xf2,0x31,0xee,0x92,0x41,0x31,0x50,0xc5,
	0x58,0x06,0x8b,0xd2,0x5f,0xac,0x6f,0xaf,
	0xf5,0xeb,0xae,0xbb,0xce,0x40,0x73,0xc6,
	0x67,0xfc,0xfa,0xc6,0x36,0xfe,0x6f,0xfb,
	0xee,0xc6,0xec,0x60,0xfe,0xfb,0x3e,0xe0,
	0xa6,0xe5,0xeb,0xaa,0xaa,0xaa,0xb6,0xfc,
	0x35,0x6f,0xa3,0xfd,0xf8,0x0f,0xfe,0x0e,
	0x1c,0x71,0x11,0xc7,0x6a,0x41,0xe3,0x10,
	0xc4,0x31,0xcf,0x05,0x37,0x3c,0x7c,0xae,
	0x7e,0x06,0x5c,0x71,0xb7,0xaf,0x62,0x7f,
	0xa4,0xfd,0x88,0xee,0x95,0x70,0x84,0xe7,
	0x08,0xa2,0x7f,0x12,0x89,0xcc,0x51,0x36,
	0xa5,0x4f,0x3f,0xff,0xe9,0x7f,0x6d,0xf8,
	0x08,0x0f,0x87,0x10,0x8f,0x2e,0x60,0x55,
	0x96,0x6f,0x38,0x8f,0x4a,0x8f,0x5c,0x8f,
	0x02,0xb2,0x58,0xff,0xaa,0x2b,0x88,0x8f,
	0x9a,0x8f,0xac,0x8f,0xbe,0x8f,0xb0,0x5a,
	0x01,0xfb,0x46,0x2b,0xf8,0x62,0x29,0x8f,
	0x03,0x9f,0x15,0x9f,0x65,0x94,0x76,0x82,
	0x1c,0xab,0x26,0x3c,0x9f,0xff,0xff,0xea,
	0x5d,0x71,0xf1,0x8f,0x67,0x97,0x5c,0xb9,
	0xdf,0x8f,0x76,0xf7,0xff,0x81,0x76,0x83,
	0x81,0x96,0x9d,0x03,0xf7,0x5f,0xa8,0x9f,
	0xba,0x9f,0xcc,0x9f,0xde,0x9f,0x22,0x20,
	0xc3,0x24,0x06,0x96,0x9c,0xe0,0xb7,0x0b,
	0xaa,0x50,0x9f,0x62,0x9c,0x9c,0xaf,0x8f,
	0x76,0x23,0xe7,0xfe,0xe5,0x73,0xb9,0xa0,
	0x97,0x9c,0x8f,0x0b,0xaa,0x3c,0x4f,0x38,
	0x8e,0xaf,0xa0,0xaf,0x92,0x73,0xef,0xfc,
	0x00,0x13,0xd2,0x1d,0xb0,0x7a,0x97,0x9c,
	0xbe,0xe7,0xaa,0xe8,0x8c,0x00,0x40,0x80,
	0xaf,0xc0,0xf6,0xaf,0x08,0xbf,0x1a,0xb7,
	0xb6,0x39,0x78,0xf2,0x35,0xbc,0xea,0xad,
	0x47,0x55,0x55,0x56,0x1d,0xaf,0x5b,0xbf,
	0x89,0xed,0xc0,0xaf,0xd2,0x50,0x83,0xb4,
	0xb1,0xd1,0x11,0x42,0xd7,0x84,0x86,0x9b,
	0xbb,0xac,0x46,0xb0,0x40,0xad,0xbf,0xbf,
	0xbf,0xd1,0xbf,0xe3,0xbf,0x71,0x8f,0xc7,
	0x53,0x8f,0x6a,0x90,0x00,0x49,0xbf,0x23,
	0xcf,0x89,0xef,0x7f,0xbc,0x66,0x93,0x8d,
	0xcf,0x1a,0xb2,0xd1,0x61,0x00,0xa6,0xe0,
	0x48,0xc5,0x82,0xcf,0x94,0xcf,0xa6,0xcb,
	0x8a,0x23,0xba,0xca,0x03,0xf2,0x00,0xd8,
	0xaf,0xde,0xcf,0xfd,0x3c,0xef,0x66,0xa4,
	0xc6,0xb9,0xa0,0xc8,0x20,0xbf,0xa1,0xfe,
	0xb7,0xc8,0xef,0xee,0xef,0xf1,0xee,0xeb,
	0xb2,0xf0,0xe7,0xa8,0x74,0x37,0x1f,0xb0,
	0x45,0xd8,0xf1,0xe3,0x77,0x77,0x04,0xfd,
	0x3c,0xe0,0x00,0xff,0x3a,0xe2,0xa4,0xc6,
	0x55,0xa0,0x78,0xd1,0x55,0xa0,0x1e,0x7f,
	0xdb,0xee,0xef,0x1b,0xad,0xe7,0xa9,0x35,
	0x36,0xa6,0xdb,0xef,0xee,0xdd,0x77,0x7f,
	0x34,0xaa,0xef,0x7f,0xbe,0xdf,0xe1,0xc7,
	0xf7,0xec,0xae,0xbc,0xc6,0xfc,0x7f,0x79,
	0xef,0xf1,0x90,0xdc,0xd2,0x81,0xff,0xdf,
	0xfe,0xe5,0xda,0xe3,0xee,0xfb,0xf4,0xdf,
	0x06,0xe4,0x7a,0x36,0xf3,0xff,0xdf,0xf7,
	0x5d,0x76,0xbf,0x1c,0xed,0xee,0xbb,0xf7,
	0xeb,0x0d,0x21,0xbc,0xc6,0xfb,0xbf,0x64,
	0xd1,0xdc,0xd2,0x97,0x00,0x48,0xea,0xef,
	0xfd,0xef,0x3b,0xb1,0x59,0xef,0xff,0xe0,
	0x1f,0xfc,0x6e,0xef,0x6c,0x9a,0xef,0x7f,
	0xbd,0x6e,0xbf,0xf7,0xb3,0xeb,0xaf,0x95,
	0xef,0x95,0x02,0xf0,0x7f,0xba,0xc5,0xe1,
	0x9f,0xee,0xef,0xfb,0xee,0xdb,0x58,0xef,
	0xe5,0xa0,0xc3,0xb8,0xa6,0xd1,0x95,0x70,
	0x75,0xe5,0xdd,0x35,0xdf,0x6c,0x9a,0xe0,
	0x9e,0xf2,0xe0,0x83,0xf7,0xeb,0xa1,0xbc,
	0xc7,0x9f,0xea,0xf6,0xfe,0xb9,0xc6,0xee,
	0xee,0x1f,0xf7,0xef,0x28,0x73,0x8e,0x21,
	0xff,0xff,0xef,0xdb,0xa6,0xd1,0x45,0xc3,
	0xf0,0xb1,0xdf,0xf3,0xe3,0x4d,0x47,0xf6,
	0xe4,0x72,0xf6,0xff,0xbb,0xae,0x2f,0xbb,
	0xf0,0xeb,0xad,0xbc,0xc6,0xfe,0x3b,0xe0,
	0xa2,0xe7,0x05,0xfa,0x75,0xf7,0xff,0xe1,
	0xf1,0xe6,0xaa,0x91,0xff,0xa3,0xf3,0xf1,
	0xc0,0x3e,0xac,0xfd,0xa1,0xc7,0xf7,0x6b,
	0xb0,0x5d,0xff,0xd3,0xfd,0x01,0xef,0x45,
	0x01,0xe8,0xfb,0x75,0x34,0x99,0xfc,0xe5,
	0xf1,0x38,0x19,0xb8,0xf0,0xb2,0xab,0x20,
	0xf7,0x77,0xc3,0xfd,0xef,0xdf,0xfc,0xb9,
	0xc6,0xe1,0x27,0xef,0xff,0xf1,0x4a,0x0f,
	0x5c,0x0f,0x03,0xcb,0xd2,0xf4,0x3a,0x05,
	0xf9,0x82,0x0f,0xe7,0x95,0x0f,0xbf,0xcf,
	0x2d,0xd9,0x99,0xfc,0xf0,0x3e,0x0b,0xf9,
	0xfc,0xd2,0x60,0xf0,0x64,0xd3,0x35,0xe4,
	0x6e,0x61,0xa4,0xe4,0x01,0xbf,0x48,0xe7,
	0x71,0x1f,0x20,0x1b,0x3a,0xf7,0xf0,0x3f,
	0xfe,0xcf,0x5c,0x19,0x00,0xb8,0xc7,0x70,
	0x14,0x3e,0x70,0x11,0x68,0x2f,0xff,0x99,
	0x1f,0xab,0x1f,0xbd,0x1f,0xef,0xff,0xff,
	0xe3,0xe7,0xbb,0x60,0xea,0xee,0xee,0x3f,
	0xff,0x8f,0x1b,0xbf,0xde,0xfe,0x49,0x01,
	0x67,0x3b,0x8e,0xd1,0xec,0xe1,0x8f,0x78,
	0x74,0xd0,0x06,0x2f,0x18,0x2b,0xfe,0xf1,
	0x0f,0x78,0xd1,0xa8,0x50,0xab,0x20,0xe1,
	0xff,0xff,0xdd,0x3e,0x36,0x25,0xb7,0xbb,
	0x3f,0xde,0x1e,0x43,0x2e,0x6c,0xed,0xef,
	0xef,0x77,0x77,0x6f,0x74,0x0a,0xff,0xff,
	0xbc,0xe7,0x7f,0x87,0x0e,0x7b,0x33,0x70,
	0x14,0xfb,0xff,0xfc,0xf5,0x03,0x78,0xd1,
	0xc0,0x6f,0x42,0xc0,0xff,0xfd,0xdd,0xaf,
	0xdb,0xff,0x7f,0xfd,0x3a,0x21,0xbb,0xa3,
	0x20,0xee,0xf1,0xee,0x6e,0x64,0xaf,0x2b,
	0x45,0xd8,0xef,0x7e,0xb7,0xef,0x9e,0xcc,
	0x2c,0xbb,0xbf,0x7a,0xf6,0x6e,0x63,0xe5,
	0x26,0xf8,0xf6,0xef,0x22,0x80,0x3f,0x6f,
	0x10,0xe0,0x00,0x01,0xfd,0x9d,0xfd,0xfe,
	0x26,0xba,0xbf,0xee,0x0a,0x3f,0x40,0xdd,
	0xef,0xe3,0x06,0xb0,0xcb,0x26,0xe4,0x74,
	0x3f,0x3f,0xff,0xf0,0x01,0x18,0x78,0xd1,
	0xcd,0x60,0x5b,0x32,0xf0,0x5d,0x62,0x3f,
	0x74,0x3f,0x22,0x38,0x2b,0x75,0xd7,0x93,
	0x3f,0x7b,0x42,0x3b,0xfd,0x9b,0xd0,0x58,
	0x40,0x67,0xfe,0x00,0x0f,0x3e,0x71,0xfa,
	0x20,0xc3,0xbd,0xff,0x20,0x37,0xe5,0xee,
	0x1e,0xcd,0x32,0x1e,0xe1,0xd4,0x3f,0x7a,
	0xcb,0x47,0xef,0x8d,0xd8,0x2f,0x37,0x44,
	0x43,0x07,0x40,0x8e,0xdf,0x2a,0x9e,0x18,
	0x4b,0xe1,0xff,0xfd,0xdf,0x2a,0x41,0x9f,
	0x32,0xb9,0xc1,0xbf,0x6e,0x60,0x38,0x4f,
	0x4a,0x4c,0x72,0xd1,0x6d,0x9b,0xbc,0x7f,
	0x8b,0x7b,0x7e,0x43,0x3a,0xfe,0x19,0x46,
	0x98,0x74,0x8d,0x41,0xfe,0x06,0x73,0xd0,
	0xff,0xb7,0x97,0x40,0xf5,0x40,0xa8,0x4f,
	0xaf,0x4f,0x35,0xab,0xcf,0xbf,0xff,0x7a,
	0xfe,0xd3,0x4f,0xe5,0x49,0xc1,0x7e,0x04,
	0xf3,0x44,0x3e,0x20,0x87,0xfe,0x4f,0x10,
	0x5f,0x22,0x57,0xd2,0x64,0x33,0x50,0x0e,
	0x42,0x3b,0xff,0x7f,0xf0,0x1b,0x44,0x28,
	0x97,0x63,0x68,0xdf,0x1e,0x08,0x78,0xcf,
	0xee,0xcd,0x4a,0x10,0x7b,0xde,0x2b,0xa8,
	0x50,0xb7,0x34,0xb2,0x59,0x10,0x21,0x6f,
	0x32,0x6d,0x98,0x73,0xe6,0x5c,0xc6,0xfa,
	0xcf,0x92,0x93,0x52,0x35,0x20,0x9c,0x47,
	0x20,0x64,0x74,0x9e,0x38,0x6f,0xe6,0x5c,
	0xba,0x5a,0x6f,0x92,0x93,0xf0,0x4a,0x11,
	0x43,0xc0,0x5b,0x12,0x96,0x63,0x7e,0xec,
	0xf3,0xce,0xff,0xec,0xff,0xb7,0x1e,0xe1,
	0xc7,0x2d,0xf0,0xfe,0x96,0x6f,0xb6,0xd7,
	0x6f,0xc3,0x8b,0xdf,0xdc,0x0f,0x3a,0xef,
	0xf5,0xf7,0xad,0x6f,0xbf,0x6f,0xc4,0x53,
	0x2b,0xd2,0xfd,0xf0,0xe6,0xa8,0x7e,0xeb,
	0x6d,0xb7,0x5b,0x7f,0x9f,0xb6,0xee,0xee,
	0xba,0xdd,0xe5,0xf1,0xf7,0x6f,0xdd,0x7f,
	0xdb,0x9f,0xdd,0xda,0xef,0xed,0xfb,0x11,
	0x7f,0xf8,0x23,0x7f,0xc4,0x5a,0xe7,0xa7,
	0x7f,0x5b,0x6d,0xb7,0xbb,0x4f,0x7f,0xae,
	0xfd,0x6e,0x55,0x7f,0x03,0x73,0xde,0x6e,
	0x7f,0xe0,0x80,0x73,0x72,0x2f,0xe2,0xab,
	0xe0,0x17,0xb0,0x74,0x0d,0x6e,0xbb,0xf9,
	0x1d,0xbb,0x7f,0xcd,0x73,0x5f,0xed,0xda,
	0xef,0xdd,0x91,0xfd,0x49,0x6e,0xdf,0x8a,
	0x1e,0x66,0x8f,0x9c,0x46,0xdf,0x87,0x7f,
	0xfb,0xb8,0xf3,0x4f,0x70,0x9e,0xeb,0xae,
	0xba,0xdc,0xfe,0x1f,0x8f,0xff,0x92,0xd3,
	0x6f,0xde,0xda,0xdf,0x1f,0xed,0xda,0x6f,
	0xdc,0x3d,0xe5,0x5f,0x4f,0x8f,0xaf,0x80,
	0xed,0x77,0x28,0x96,0x7f,0xfc,0xa1,0x56,
	0x5b,0xed,0xb6,0xff,0xeb,0x7f,0xaf,0x1b,
	0xa1,0xc7,0x3d,0x30,0xee,0xaf,0x8f,0xa5,
	0xd4,0xef,0x99,0x80,0xec,0x3a,0x9f,0x20,
	0x3b,0x8f,0x5d,0xe6,0xba,0x8c,0xea,0x44,
	0xdc,0x10,0xfb,0xa7,0x95,0xb0,0x71,0xc7,
	0xfb,0x7f,0xaf,0xe6,0xa1,0x1d,0x95,0x4f,
	0x9b,0xde,0xd9,0x01,0xdf,0x9b,0x50,0x03,
	0x9b,0x8d,0x57,0x1b,0x9e,0xfd,0x40,0x76,
	0x45,0x37,0x96,0x4e,0x4c,0x71,0xfb,0x7f,
	0xb7,0x47,0x9f,0xb3,0x95,0xdd,0x62,0x92,
	0xfc,0xd7,0x7b,0x39,0xa4,0xf8,0x7f,0xe1,
	0xca,0x1f,0xc6,0x8f,0x1d,0x77,0xfa,0xfa,
	0xbe,0x88,0xe4,0x27,0x9b,0x97,0xec,0x4f,
	0xf3,0xcf,0xfc,0xff,0xaa,0x9f,0xc1,0x55,
	0xef,0x09,0x70,0x9f,0x07,0xfb,0xff,0xec,
	0x1b,0xcd,0x99,0xc5,0x44,0xfb,0xff,0xbf,
	0xde,0xb2,0xef,0xba,0xed,0x77,0xf6,0x49,
	0xdb,0xa9,0x80,0xa9,0x84,0x0f,0xe6,0x00,
	0x29,0x50,0x7f,0x23,0x20,0xc0,0x37,0x97,
	0x15,0xaf,0x7e,0xaf,0x8e,0x90,0x10,0x7a,
	0x3d,0xa5,0xdf,0xde,0x05,0xba,0x48,0xad,
	0x7f,0xe2,0xd0,0xb2,0x50,0xb4,0xe0,0xdf,
	0x90,0x65,0xaf,0x70,0xda,0xaf,0x79,0x9a,
	0x96,0xab,0x00,0x41,0xfb,0xdf,0xfe,0xab,
	0xa2,0x13,0xee,0xab,0x6e,0x80,0xb5,0xa6,
	0xef,0xbf,0xa3,0xbe,0xa2,0xca,0xaf,0xb8,
	0x3f,0xbf,0x2c,0xb9,0xfa,0xaf,0xfb,0xd0,
	0x71,0xab,0xa1,0x37,0x72,0x14,0xb9,0x07,
	0xcd,0x90,0xc0,0xa2,0xbf,0xff,0xfd,0x64,
	0xaf,0xfe,0xa1,0xbf,0xff,0xef,0x1f,0xbe,
	0x8e,0x38,0xdd,0x7f,0x8f,0xee,0xc7,0xb8,
	0x71,0xc2,0xf0,0x96,0xac,0xfe,0xa8,0x80,
	0xfb,0xdf,0xef,0xba,0x1f,0x86,0x1d,0x01,
	0x4f,0x14,0xb9,0x97,0x92,0x96,0xb0,0xa8,
	0x80,0xa8,0x86,0x98,0xbf,0x07,0xc8,0xff,
	0xee,0xef,0xdd,0x75,0xd7,0x6b,0x77,0xed,
	0xdf,0xbb,0xbb,0xae,0xba,0xee,0xfe,0x1f,
	0xfb,0xdf,0x6c,0xab,0xe0,0x6e,0x80,0xee,
	0x73,0xde,0xb9,0xfe,0x7f,0xc0,0xa1,0xf8,
	0x2d,0x95,0xf8,0xbf,0x0a,0xcf,0x75,0xd7,
	0x77,0x77,0xeb,0x63,0xbf,0x5b,0x23,0xcf,
	0xd1,0xb1,0x40,0x20,0xff,0xdb,0xb7,0xf0,
	0x81,0x73,0x4e,0xa7,0x6b,0x81,0xc0,0xa1,
	0xce,0x93,0x5a,0xcf,0x6c,0xcf,0xef,0x3d,
	0xeb,0x80,0xc2,0x83,0x5b,0xae,0xc2,0x89,
	0xcf,0xdf,0x91,0x7f,0xfe,0xff,0xe7,0xfd,
	0xff,0xf6,0xfb,0xa6,0xca,0xe1,0xcf,0xc0,
	0xa1,0x3a,0xf5,0xc0,0xcf,0x6e,0xce,0xf7,
	0x76,0x37,0xff,0x6b,0x77,0xe7,0xba,0xeb,
	0xae,0xfa,0x6e,0x24,0xee,0xcf,0x33,0xd5,
	0xfb,0x86,0x41,0x28,0xd7,0xf3,0xc0,0xa1,
	0xa9,0xd6,0xfc,0x25,0xdf,0xa7,0xbd,0xeb,
	0x0d,0xd7,0x5d,0x77,0xe7,0x1f,0xc6,0xe8,
	0x71,0xc6,0xb0,0x52,0xdf,0xb4,0x8f,0xf5,
	0x53,0x8f,0x7b,0xff,0xff,0x78,0xc9,0xdf,
	0xf5,0xdf,0xa1,0x74,0xdd,0x5f,0x7d,0xd7,
	0x7f,0x77,0xeb,0x2a,0xb1,0xfe,0xc2,0xbf,
	0x3c,0xc8,0xdf,0xfb,0xd3,0x8b,0xff,0xff,
	0x47,0x2d,0xef,0x59,0xef,0xca,0x08,0xe5,
	0xb5,0x11,0xe0,0xed,0x15,0xef,0xd3,0x24,
	0xfe,0xf1,0x0f,0xfd,0xf8,0x6f,0x83,0x4f,
	0xed,0xce,0x90,0x80,0xd9,0x53,0xef,0xfe,
	0xc3,0xe9,0x01,0xff,0xbe,0xce,0x38,0xff,
	0x8f,0xf9,0xee,0x79,0xef,0xff,0x34,0xfe,
	0xee,0xfd,0xf7,0xb7,0x00,0x6e,0x83,0xb8,
	0xef,0xaf,0xef,0x24,0xff,0xd7,0x5f,0xe5,
	0xef,0xf7,0xe1,0xe0,0x13,0xc0,0x1c,0xff,
	0x13,0xff,0x88,0xff,0x37,0xff,0x99,0xac,
	0xf4,0xe2,0xff,0xbb,0xc0,0x4f,0x18,0xcd,
	0xff,0xc5,0xff,0xf1,0xff,0xa0,0xff,0xb2,
	0xfb,0xfc,0x3c,0x01,0x7b,0x9b,0x5b,0x34,
	0x0f,0x2c,0x0f,0x58,0x0f,0x07,0x0f,0x29,
	0x56,0x92,0xe0,0x03,0xdb,0xfd,0xb2,0x53,
	0x48,0x0f,0x3f,0x0f,0xb4,0x0f,0x63,0x0f,
	0x75,0x0f,0x1f,0xff,0xfd,0xd7,0xfd,0xbb,
	0xa7,0x0f,0x9e,0x0f,0x13,0x1f,0x08,0x25,
	0x1f,0xe4,0x5f,0xe6,0x05,0xbe,0xef,0x0f,
	0x01,0x1f,0x76,0x1f,0x88,0x1f,0xfc,0x37,
	0x1f,0x8c,0x12,0xf0,0x1f,0xfc,0x38,0x7e,
	0xc7,0x00,0x6f,0x1f,0x66,0x1f,0xdb,0x1f,
	0xed,0x1f,0x9c,0x1f,0xcf,0x1c,0x09,0x2f,
	0xcf,0x1f,0x00,0x44,0x2f,0xf3,0x1f,0x05,
	0x2f,0x32,0x2f,0x8c,0x2f,0x84,0x2f,0xb0,
	0x2f,0xab,0x15,0x00,0xbd,0xd1,0x5d,0xa1,
	0xd2,0x2f,0x9c,0x2f,0xdc,0x2f,0x08,0x3f,
	0x1a,0x3f,0xc9,0x2f,0x00,0xf6,0x2f,0x50,
	0x3f,0x48,0x3f,0x74,0x3f,0x86,0x3f,0x98,
	0x3f,0xaa,0x3f,0x59,0x3f,0x00,0xce,0x3f,
	0xe0,0x3f,0xf2,0x3f,0x04,0x4f,0x16,0x4f,
	0xc5,0x3f,0x3a,0x4f,0x4c,0x4f,0x00,0x5e,
	0x4f,0x70,0x4f,0x1f,0x4f,0x82,0x4f,0xa6,
	0x4f,0xb8,0x4f,0xca,0x4f,0xdc,0x4f,0x00,
	0x8b,0x4f,0x00,0x5f,0x12,0x5f,0x24,0x5f,
	0x36,0x5f,0x48,0x5f,0xf7,0x4f,0x6c,0x5f,
	0x00,0x7e,0x5f,0x90,0x5f,0xa2,0x5f,0x51,
	0x5f,0xc6,0x5f,0xd8,0x5f,0xea,0x5f,0xfc,
	0x5f,0x00,0x0e,0x6f,0xbd,0x5f,0x32,0x6f,
	0x44,0x6f,0x56,0x6f,0x68,0x6f,0x17,0x6f,
	0x8c,0x6f,0x00,0x9e,0x6f,0xb0,0x6f,0xc2,
	0x6f,0xd4,0x6f,0x83,0x6f,0xf8,0x6f,0x0a,
	0x7f,0x1c,0x7f,0x00,0x2e,0x7f,0x40,0x7f,
	0x52,0x7f,0x64,0x7f,0x76,0x7f,0x88,0x7f,
	0x9a,0x7f,0xac,0x7f,0x40,0xbe,0x7f,0xd0,
	0x7f,0xe2,0x7f,0xf4,0x7f,0x06,0x8f,0x18,
	0x8f,0xff
};

#endif	// _WIN32
